import React from "react";
import {
    Dimensions,
    Modal,
    ScrollView,
    StatusBar,
    StyleSheet,
    TouchableOpacity,
    View,
    TouchableWithoutFeedback,
    Image,
    LayoutAnimation,
} from "react-native";
import {RobotoText} from "components/utils/texts/StyledText";
import {appColor} from "constants/Colors";
import {AppModules} from "navigation/Screens";
import {useNavigation} from "@react-navigation/native";
import {StackNavigationProp} from "@react-navigation/stack";
import {CardItem} from "components/library/CardItem";
import {ProfileCard} from "components/library/ProfileCard";
import {CustomButton} from "components/library/CustomButton";
import {CardSettingsItem} from "components/library/CardSettingsItem";
import {CustomInput} from "components/library/CustomInput";
import {RobotoBoldText} from "components/utils/texts/StyledText";
import {getText} from "../locales/Locales";
import DarkModeIcon from "assets/svg/moonLight.svg";
import LightModeIcon from "assets/svg/moonDark.svg";
import {useTheme} from "react-native-paper";
import {PreferencesContext} from "../context/PrefferencesContext";
import NavigationArrowIcon from 'assets/svg/navigationArrowIcon.svg';
import ContactsIcon from 'assets/svg/contactsIcon.svg';
import { TouchableOpacity, StyleSheet, Text } from 'react-native';
import {RobotoBoldText, RobotoText} from "components/utils/texts/StyledText";
import {appColor} from "constants/Colors";
import {useTheme} from "react-native-paper";
import {Dimensions, StyleSheet, View, TextInput} from "react-native";
import {RobotoBoldText, RobotoText} from "components/utils/texts/StyledText";
import {appColor} from "constants/Colors";
import {useTheme} from "react-native-paper";
import {Dimensions, StyleSheet, View, TouchableWithoutFeedback} from "react-native";
import {Image} from "react-native-elements";
import {RobotoBoldText, RobotoText} from "components/utils/texts/StyledText";
import { useTheme } from 'react-native-paper';
import ActiveCircleIcon from 'assets/svg/circleIcon2.svg';
import {Dimensions, ImageBackground, StyleSheet, TouchableHighlight, View} from "react-native";
import {RobotoBoldText, RobotoText} from "components/utils/texts/StyledText";
import {appColor} from "constants/Colors";
import {useTheme} from "react-native-paper";
import ArrowRightIcon from 'assets/svg/arrowRight.svg';
import {ShortCutEnhancedView} from "./ShortCutEnhancedView";
import {ShortCut} from "../../screens/HomeScreen";
import { TabActions } from '@react-navigation/native';

const FAB_SIZE = 56;
const {width: WINDOW_WIDTH} = Dimensions.get('window');

interface Props {
    navigation: any
}

interface State {
    profileVisible: boolean,
    firstStepsVisible: boolean,
    modalVisible: boolean,
    alephVisible: boolean,
    jobsPefVisible: boolean,
    xnameValid: boolean,
    passwordValid: boolean,
    xname: string,
    password: string,
    settingsVisible: boolean,
    darkMode: boolean
    foodPointVisible: boolean
}

export interface ShortCut {
    label: string;
    contentColor: string;
    icon: JSX.Element
    target: string
}

export const HomeScreen: React.FC<Props> = () => {

    const navigation = useNavigation<StackNavigationProp<any>>();

    const theme = useTheme();
    const { toggleTheme } = React.useContext(PreferencesContext);

    const firstStepsShortCuts: ShortCut[] = [
        { "label": getText('homeScreen.firstStepsCard.shortCutLabel.navigation'), "contentColor": "#0BCE83", "icon": <NavigationArrowIcon height={15} width={15}/>, "target": 'https://jsemprvak.pef.czu.cz/plan-arealu' },
        { "label": getText('homeScreen.firstStepsCard.shortCutLabel.contacts'), "contentColor": "#387FE9", "icon": <ContactsIcon height={15} width={15}/>, "target": 'https://www.pef.czu.cz/cs/r-7008-studium/r-7025-studijni-oddeleni'}
    ];

    const [ state, setState ] = React.useState<State>({
        profileVisible: true,
        firstStepsVisible: false,
        modalVisible: false,
        alephVisible: true,
        jobsPefVisible: true,
        xname: "",
        password: "",
        xnameValid: null,
        passwordValid: null,
        settingsVisible: false,
        darkMode: false,
        foodPointVisible: true
    });

    const themeIcon = (): JSX.Element => {
        return state.darkMode ?
                <DarkModeIcon height={styles.themeIconSize.height} width={styles.themeIconSize.width}/>
            :
            <LightModeIcon height={styles.themeIconSize.height} width={styles.themeIconSize.height}/>;
    }

    const themeStatusBar = (): JSX.Element => {
        return state.darkMode ?
            <StatusBar barStyle="light-content"/>
            :
            <StatusBar barStyle="dark-content"/>;
    }

    const renderSettingsIcon = () => {
        const imgSource = state.settingsVisible? require('assets/canceIcon.png') : require('assets/addIcon.png');
        return (
            <Image
                source={imgSource}
                style={{flex:1, height: 23, tintColor: theme.colors.text}}
                resizeMode="contain"
            />
        )
    };

    const changeSettingsLayout = () => {
        LayoutAnimation.configureNext(LayoutAnimation.Presets.easeInEaseOut);
        setState({...state, settingsVisible: !state.settingsVisible});
    };

    const changeAppSettingsLayout = () => {
        toggleTheme();
        LayoutAnimation.configureNext(LayoutAnimation.Presets.easeInEaseOut);
        setState({...state, darkMode: !state.darkMode});
    };

    const getFirstStepsResponse = (result) => {
        setState({...state, firstStepsVisible: !result});
    }
    const getAlephResponse = (result) => {
        setState({...state, alephVisible: !result});
    }
    const getFoodPointResponse = (result) => {
        setState({...state, foodPointVisible: !result});
    }
    const getJobsPefResponse = (result) => {
        setState({...state, jobsPefVisible: !result});
    }
    const getXnameValue = (result) => {
        setState({...state, xname: result});
    }
    const getPasswordValue = (result) => {
        setState({...state, password: result});
    }

    // @ts-ignore
    return (
        <View style={styles.container}>
            {themeStatusBar()}
            <ScrollView
                style={[styles.scrollView, {opacity: state.modalVisible ? 0.85 : 1, backgroundColor: theme.colors.background}]}
                contentContainerStyle={[styles.scrollViewContent, {paddingBottom: FAB_SIZE * 2}]}>
                {state.profileVisible && <ProfileCard
                    title={getText("homeScreen.profileCard.statusLoggedOut")}
                    description={getText("homeScreen.profileCard.actionStatus")}
                    balance={getText("homeScreen.profileCard.emptyBalance")}
                    balanceDescription={getText("homeScreen.profileCard.cardBalanceDescription")}
                    setState={setState}
                    state={state}
                    visible={true}
                />}

                <View style={{ maxHeight: 91, marginTop: 5, marginBottom: state.settingsVisible ? 50 : 5}}>
                    <View style={styles.cardSettingsMenu}>
                        <RobotoBoldText style={{flex:6, fontSize: 16, lineHeight: 23, color: theme.colors.text}}>{getText("homeScreen.homeScreenTitle")}</RobotoBoldText>
                        <TouchableWithoutFeedback onPress={() => changeSettingsLayout()}>
                            {renderSettingsIcon()}
                        </TouchableWithoutFeedback>
                        <TouchableOpacity onPress={() => changeAppSettingsLayout()}>
                            {themeIcon()}
                        </TouchableOpacity>
                    </View>
                    <View style={{ height: state.settingsVisible ? null : 0, overflow: 'hidden' }}>
                        <ScrollView style={[styles.cardSettingsScrollView, {backgroundColor: theme.colors.background, borderBottomColor: theme.colors.background, borderTopColor: theme.colors.background}]} horizontal={true} showsHorizontalScrollIndicator={false}>
                            <TouchableWithoutFeedback onPress={() => [calc(), setState({ selected: !state.selected})]}>
					            <View style={[styles.container, {borderColor: state.selected ? theme.colors.text : 'transparent', backgroundColor: state.selected ? 'transparent': theme.colors.surface}]}>
					                <View style={[styles.heading]}>
					                    <View style={{flex: 3}}>
					                        <RobotoBoldText style={{fontSize:14, color: theme.colors.text}} numberOfLines={1}>{props.icon+props.title}</RobotoBoldText>
					                    </View>
					                    <View style={{flex: 1, alignItems: 'flex-end', marginRight: 14}}>
					                        <SettingsIcon selected={state.selected}/>
					                    </View>
					                </View>
					                <RobotoText style={[styles.description, { color: theme.colors.text}]} numberOfLines={2}>{props.description}</RobotoText>
					            </View>
					        </TouchableWithoutFeedback>
					        <TouchableWithoutFeedback onPress={() => [calc(), setState({ selected: !state.selected})]}>
					            <View style={[styles.container, {borderColor: state.selected ? theme.colors.text : 'transparent', backgroundColor: state.selected ? 'transparent': theme.colors.surface}]}>
					                <View style={[styles.heading]}>
					                    <View style={{flex: 3}}>
					                        <RobotoBoldText style={{fontSize:14, color: theme.colors.text}} numberOfLines={1}>{props.icon+props.title}</RobotoBoldText>
					                    </View>
					                    <View style={{flex: 1, alignItems: 'flex-end', marginRight: 14}}>
					                        <SettingsIcon selected={state.selected}/>
					                    </View>
					                </View>
					                <RobotoText style={[styles.description, { color: theme.colors.text}]} numberOfLines={2}>{props.description}</RobotoText>
					            </View>
					        </TouchableWithoutFeedback>
					        <TouchableWithoutFeedback onPress={() => [calc(), setState({ selected: !state.selected})]}>
					            <View style={[styles.container, {borderColor: state.selected ? theme.colors.text : 'transparent', backgroundColor: state.selected ? 'transparent': theme.colors.surface}]}>
					                <View style={[styles.heading]}>
					                    <View style={{flex: 3}}>
					                        <RobotoBoldText style={{fontSize:14, color: theme.colors.text}} numberOfLines={1}>{props.icon+props.title}</RobotoBoldText>
					                    </View>
					                    <View style={{flex: 1, alignItems: 'flex-end', marginRight: 14}}>
					                        <SettingsIcon selected={state.selected}/>
					                    </View>
					                </View>
					                <RobotoText style={[styles.description, { color: theme.colors.text}]} numberOfLines={2}>{props.description}</RobotoText>
					            </View>
					        </TouchableWithoutFeedback>
					        <TouchableWithoutFeedback onPress={() => [calc(), setState({ selected: !state.selected})]}>
					            <View style={[styles.container, {borderColor: state.selected ? theme.colors.text : 'transparent', backgroundColor: state.selected ? 'transparent': theme.colors.surface}]}>
					                <View style={[styles.heading]}>
					                    <View style={{flex: 3}}>
					                        <RobotoBoldText style={{fontSize:14, color: theme.colors.text}} numberOfLines={1}>{props.icon+props.title}</RobotoBoldText>
					                    </View>
					                    <View style={{flex: 1, alignItems: 'flex-end', marginRight: 14}}>
					                        <SettingsIcon selected={state.selected}/>
					                    </View>
					                </View>
					                <RobotoText style={[styles.description, { color: theme.colors.text}]} numberOfLines={2}>{props.description}</RobotoText>
					            </View>
					        </TouchableWithoutFeedback>
                        </ScrollView>
                    </View>
                </View>
		        <View style={styles.container}>
		                <View>
		                    <ImageBackground source={props.imagePath} style={styles.cover} imageStyle={{resizeMode: 'cover'}}>
		                        {shortCutEnhancedView}
		                    </ImageBackground>
		                    <TouchableHighlight onPress={() => props.tabBarShortCutTarget ? navigation.dispatch(tabBarShortCutToAction) : navigation.navigate(props.target)}>
		                    <View style={[styles.cardBar, {backgroundColor: theme.colors.surface}]}>
		                        <View style={{flexDirection: "row"}}>
		                            <View style={{flex:6}}>
		                                <RobotoBoldText style={[styles.header, {color: theme.colors.text}]} numberOfLines={1}>{props.title}</RobotoBoldText>
		                                <RobotoText style={[styles.description, {color: theme.colors.placeholder}]} numberOfLines={1}>{props.description}</RobotoText>
		                            </View>
		                            <View style={{flex: 1, justifyContent: "center"}}>
		                                <ArrowRightIcon height={20} stroke={theme.colors.placeholder} style={{marginLeft: 15}}/>
		                            </View>
		                        </View>
		                    </View>
		                    </TouchableHighlight>
		                </View>
		        </View>
		        <View style={styles.container}>
		                <View>
		                    <ImageBackground source={props.imagePath} style={styles.cover} imageStyle={{resizeMode: 'cover'}}>
		                        {shortCutEnhancedView}
		                    </ImageBackground>
		                    <TouchableHighlight onPress={() => props.tabBarShortCutTarget ? navigation.dispatch(tabBarShortCutToAction) : navigation.navigate(props.target)}>
		                    <View style={[styles.cardBar, {backgroundColor: theme.colors.surface}]}>
		                        <View style={{flexDirection: "row"}}>
		                            <View style={{flex:6}}>
		                                <RobotoBoldText style={[styles.header, {color: theme.colors.text}]} numberOfLines={1}>{props.title}</RobotoBoldText>
		                                <RobotoText style={[styles.description, {color: theme.colors.placeholder}]} numberOfLines={1}>{props.description}</RobotoText>
		                            </View>
		                            <View style={{flex: 1, justifyContent: "center"}}>
		                                <ArrowRightIcon height={20} stroke={theme.colors.placeholder} style={{marginLeft: 15}}/>
		                            </View>
		                        </View>
		                    </View>
		                    </TouchableHighlight>
		                </View>
		        </View>
		        <View style={styles.container}>
		                <View>
		                    <ImageBackground source={props.imagePath} style={styles.cover} imageStyle={{resizeMode: 'cover'}}>
		                        {shortCutEnhancedView}
		                    </ImageBackground>
		                    <TouchableHighlight onPress={() => props.tabBarShortCutTarget ? navigation.dispatch(tabBarShortCutToAction) : navigation.navigate(props.target)}>
		                    <View style={[styles.cardBar, {backgroundColor: theme.colors.surface}]}>
		                        <View style={{flexDirection: "row"}}>
		                            <View style={{flex:6}}>
		                                <RobotoBoldText style={[styles.header, {color: theme.colors.text}]} numberOfLines={1}>{props.title}</RobotoBoldText>
		                                <RobotoText style={[styles.description, {color: theme.colors.placeholder}]} numberOfLines={1}>{props.description}</RobotoText>
		                            </View>
		                            <View style={{flex: 1, justifyContent: "center"}}>
		                                <ArrowRightIcon height={20} stroke={theme.colors.placeholder} style={{marginLeft: 15}}/>
		                            </View>
		                        </View>
		                    </View>
		                    </TouchableHighlight>
		                </View>
		        </View>
		        <View style={styles.container}>
		                <View>
		                    <ImageBackground source={props.imagePath} style={styles.cover} imageStyle={{resizeMode: 'cover'}}>
		                        {shortCutEnhancedView}
		                    </ImageBackground>
		                    <TouchableHighlight onPress={() => props.tabBarShortCutTarget ? navigation.dispatch(tabBarShortCutToAction) : navigation.navigate(props.target)}>
		                    <View style={[styles.cardBar, {backgroundColor: theme.colors.surface}]}>
		                        <View style={{flexDirection: "row"}}>
		                            <View style={{flex:6}}>
		                                <RobotoBoldText style={[styles.header, {color: theme.colors.text}]} numberOfLines={1}>{props.title}</RobotoBoldText>
		                                <RobotoText style={[styles.description, {color: theme.colors.placeholder}]} numberOfLines={1}>{props.description}</RobotoText>
		                            </View>
		                            <View style={{flex: 1, justifyContent: "center"}}>
		                                <ArrowRightIcon height={20} stroke={theme.colors.placeholder} style={{marginLeft: 15}}/>
		                            </View>
		                        </View>
		                    </View>
		                    </TouchableHighlight>
		                </View>
		        </View>

    			}
                <View style={{ height: 0 }}>
                    <Modal visible={state.modalVisible}
                           animationType="slide"
                           transparent={true}>
                        <TouchableOpacity onPress={() => setState({...state, modalVisible: false})} style={{
                            width: '100%',
                            height: '35%'
                        }}/>
                        <TouchableWithoutFeedback
                            onPressOut={(e) => {
                                if (e.nativeEvent.locationY < 50) {
                                    setState({...state, modalVisible: false})
                                }}
                            }>
                            <View style={[styles.loginBar, {backgroundColor: theme.colors.background}]}>
                                <View style={{height: 3, width: 26, backgroundColor: theme.colors.background, position: 'absolute', top: 11}}/>
                                <RobotoText style={[styles.loginBarInfo, {color: theme.colors.text}]}>{getText("homeScreen.loginBar.info")}</RobotoText>
						        <View style={[styles.container, {backgroundColor: theme.colors.background}]}>
						            <RobotoBoldText style={[styles.label, {color: theme.colors.text}]}>{props.label}</RobotoBoldText>
						            <TextInput  style={[styles.input, {backgroundColor: theme.colors.surface, color: theme.colors.text}]}
						                        secureTextEntry={props.secureTextEntry}
						                        pattern={[
						                            '^.{4,}$', // min 4 chars - (because of our test / test account)  in future we can add pattern check just by xnameValid[0, 1, 2] ...
						                            '(?=.*\\d)', // number required
						                        ]}
						                        value={state.value}
						                        onChangeText={(text) => {
						                                setState({value: text})
						                                calc();
						                            }
						                        }
						                        //onValidation={xnameValid => props.setState({...props.state, xnameValid})}
						                        //onValidation={passwordValid => setState({...state, passwordValid})}
						                        //onChangeText={(passwordInput) => setState({...state, password: passwordInput})}
						                    />
						        </View>
                                <CustomInput
                                    label={getText("homeScreen.loginBar.password")}
                                    secureTextEntry={true}
                                    setState={setState}
                                    state={state}
                                    callback={getPasswordValue.bind(this)}
                                />
						        <View style={[styles.container, {backgroundColor: theme.colors.background}]}>
						            <RobotoBoldText style={[styles.label, {color: theme.colors.text}]}>{props.label}</RobotoBoldText>
						            <TextInput  style={[styles.input, {backgroundColor: theme.colors.surface, color: theme.colors.text}]}
						                        secureTextEntry={props.secureTextEntry}
						                        pattern={[
						                            '^.{4,}$', // min 4 chars - (because of our test / test account)  in future we can add pattern check just by xnameValid[0, 1, 2] ...
						                            '(?=.*\\d)', // number required
						                        ]}
						                        value={state.value}
						                        onChangeText={(text) => {
						                                setState({value: text})
						                                calc();
						                            }
						                        }
						                        //onValidation={xnameValid => props.setState({...props.state, xnameValid})}
						                        //onValidation={passwordValid => setState({...state, passwordValid})}
						                        //onChangeText={(passwordInput) => setState({...state, password: passwordInput})}
						                    />
						        </View>
                                <CustomInput
                                    label={getText("homeScreen.loginBar.password")}
                                    secureTextEntry={true}
                                    setState={setState}
                                    state={state}
                                    callback={getPasswordValue.bind(this)}
                                />
						        <TouchableOpacity onPress={props.onPress} style={[containerStyles, props.buttonStyle, {backgroundColor: theme.colors.text}]} disabled={props.disabled}>
						            <RobotoText style={[textStyles, props.textStyle, {color: theme.colors.background}]}>{props.title}</RobotoText>
						        </TouchableOpacity>
                            </View>
                        </TouchableWithoutFeedback>
                    </Modal>
                </View>
            </ScrollView>
        </View>
    );
}

const getStyles = (
    theme,
    size,
    disabled,
) => {
    const containerStyles = [styles.containerDefault];
    const textStyles = [styles.textDefault];

    //theme
    if(theme === 'black'){
        containerStyles.push(styles.containerBlack);
        textStyles.push(styles.textWhite);
    } else if(theme === 'white'){
        containerStyles.push(styles.containerWhite);
        textStyles.push(styles.textBlack);
    } else if(theme === 'blue'){
        containerStyles.push(styles.containerBlue);
        textStyles.push(styles.textWhite);
    } else if(theme === 'red'){
        containerStyles.push(styles.containerRed);
        textStyles.push(styles.textWhite);
    } else if(theme === 'grey'){
        containerStyles.push(styles.containerGrey);
        textStyles.push(styles.textGrey);
    } else {
        containerStyles.push(styles.containerBlack);
        textStyles.push(styles.textWhite);
    }

    //size
    if(size === 'large'){
        containerStyles.push(styles.containerLarge);
        textStyles.push(styles.textLarge);
    } else if(size === 'middle'){
        containerStyles.push(styles.containerMiddle);
        textStyles.push(styles.textMiddle);
    } else if(size === 'small') {
        containerStyles.push(styles.containerSmall);
        textStyles.push(styles.textSmall);
    } else {
        containerStyles.push(styles.containerLarge);
        textStyles.push(styles.textLarge);
    }

    //disabled
    if(disabled){
        containerStyles.push(styles.containerGrey);
        textStyles.push(styles.textGrey);
    }

    return {containerStyles, textStyles};
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        color: "#090C1A"
    },
    scrollView: {
        flex: 1,
        width: "100%"
    },
    scrollViewContent: {
        alignItems: "center",
        marginTop: 20,
    },
    loginBar:{
        backgroundColor: appColor.white,
        width: '100%',
        justifyContent: 'center',
        alignItems: 'center',
        flex: 5,
        borderTopLeftRadius: 20,
        borderTopRightRadius: 20,
    },
    loginBarInfo:{
        paddingLeft: 45,
        paddingRight: 45,
        paddingBottom: 25,
        position: 'relative',
        top: 0,
        textAlign: 'center',
        color: appColor.gray,
        fontSize: 14,
    },
    cardSettingsMenu: {
        justifyContent: 'center',
        alignItems: 'center',
        width: WINDOW_WIDTH - 40,
        flexDirection: "row",
        margin: 10,
        marginLeft: 20,
        marginRight: 20,
    },
    cardSettingsScrollView: {
        backgroundColor: appColor.white,
        borderBottomWidth: 3,
        borderBottomColor: '#EDEDED',
        borderTopWidth: 3,
        borderTopColor: '#EDEDED',
    },
    themeIconSize: {
        width: 15,
        height: 15
    },
    container1:{
        height: 65,
        width: 141,
        marginLeft: 10,
        marginRight: 10,
        marginTop: 10,
        borderRadius: 5,
        borderWidth: 2,
    },
    heading1:{
        flexDirection: "row",
        height: '40%',
        width: '100%',
        marginTop: 5,
        marginLeft: 8,
    },
    description1:{
        fontSize: 12,
        marginLeft: 13,
        marginRight: 20,
    }
    container2:{
        //flexDirection: "column",
        height: 250,
        width: WINDOW_WIDTH - 36,
        marginTop: 10,
        borderRadius: 20,
        overflow: "hidden",
        backgroundColor: appColor.black
    },
    cover2: {
        //flex: 2,
        height: 180,
    },
    cardBar2: {
        //flex: 1,
        height: 70,
        backgroundColor: appColor.white,
        padding: 15,
    },
    header2: {
        color: appColor.black,
        opacity: 0.85,
        fontSize: 18,
    },
    description2: {
        color: appColor.gray,
        marginTop: 3,
        fontSize: 14,
    },
    container3: {
        flexDirection: 'column',
        marginBottom: 30,
        width: '85%',
    },
    label3: {
        marginBottom: 5,
    },
    input3: {
        height: 50,
        width: '100%',
        backgroundColor: appColor.white,
        borderRadius: 5,
        borderWidth: 1,
        borderColor: 'rgba(228, 228, 228, 0.6)',
        paddingLeft: 20,
        color: appColor.black,
    },
        containerDefault: {
        display: 'flex',
        height: 50,
        marginTop: 10,
        marginBottom: 10,
        borderRadius: 5,
        justifyContent: 'center',
        alignItems: 'center',

        shadowColor: appColor.black,
        shadowOffset: {
            width: 0,
            height: 2,
        },
        shadowOpacity: 0.5,
        shadowRadius: 2.62,
        elevation: 4,
    },
    containerBlack: {
        backgroundColor: appColor.black,
    },
    containerWhite: {
        backgroundColor: appColor.white,
    },
    containerBlue: {
        backgroundColor: appColor.blue, //missing linear-gradient(188.8deg, #3D639D 3.26%, #343D63 100%);
    },
    containerRed: {
        backgroundColor: appColor.red,
    },
    containerGrey: {
        backgroundColor: appColor.lightGray,
    },
    containerLarge: {
        width: '85%',
    },
    containerMiddle: {
        width: '55%',
    },
    containerSmall: {
        width: '35%',
    },
    // Text Styles
    textDefault: {
        paddingLeft: 10,
        paddingRight: 10,
    },
    textBlack: {
        color: appColor.black,
    },
    textWhite: {
        color: appColor.white,
    },
    textGrey: {
        color: appColor.gray,
    },
    textLarge:{
        fontSize: 16,
    },
    textMiddle:{
        fontSize: 16,
    },
    textSmall:{
        fontSize: 16,
    },
});
