import React, {useState} from 'react';
import {registerRootComponent} from 'expo';
import * as Font from 'expo-font'
//import * as Sentry from 'sentry-expo';
import I18n from 'i18n-js';
import {navigationRef} from "navigation/RootNavigation";
import {StyleConstants} from "style/StyleConstants";
import {Text, View} from "react-native";
import {
    NavigationContainer,
    DarkTheme as NavigationDarkTheme,
    DefaultTheme as NavigationDefaultTheme,
} from '@react-navigation/native';
import {
    DarkTheme as PaperDarkTheme,
    DefaultTheme as PaperDefaultTheme,
    Provider as PaperProvider,
} from 'react-native-paper';
import merge from 'deepmerge';
import AppNavigator from "navigation/TabNavigator";
import { PreferencesContext } from './context/PrefferencesContext';
import {InitialProps} from "expo/build/launch/withExpoRoot.types";


// Enable fallbacks if you want `en-US`
// and `en-GB` to fallback to `en`
I18n.fallbacks = true;

// Available languages
I18n.translations = {
    'en': require('locales/en'),
    'cs': require('locales/cs'),
};

/*Sentry.init({
    enableInExpoDevelopment: true,
    debug: true
});*/

const CombinedDefaultTheme = merge(PaperDefaultTheme, NavigationDefaultTheme);
const CombinedDarkTheme = merge(PaperDarkTheme, NavigationDarkTheme);

const App: React.FC<InitialProps> = (initialProps: InitialProps) => {
    const [isThemeDark, setIsThemeDark] = React.useState(false);

    let theme = isThemeDark ? CombinedDarkTheme : CombinedDefaultTheme;

    const toggleTheme = React.useCallback(() => {
        return setIsThemeDark(!isThemeDark);
    }, [isThemeDark]);

    const preferences = React.useMemo(
        () => ({
            toggleTheme,
            isThemeDark,
        }),
        [toggleTheme, isThemeDark]
    );


    const [loading, setLoading] = React.useState<boolean>(true);

    React.useEffect(() => {
        const bootstrapAsync = async () => {
            await Font.loadAsync({
                "space-mono": require("assets/fonts/SpaceMono-Regular.ttf"),
                "roboto": require("assets/fonts/Roboto/Roboto-Regular.ttf"),
                "roboto-bold": require("assets/fonts/Roboto/Roboto-Bold.ttf"),
            });

            setLoading(false);
        };

        bootstrapAsync().catch(error => console.log(error));
    }, []);


    if (loading) {
        return (
            <View>
                <Text>Loading app - here will be our splash screen</Text>
            </View>
        );
    } else {
        return (
            <PreferencesContext.Provider value={preferences}>
                <PaperProvider theme={theme}>
                    <NavigationContainer ref={navigationRef} theme={CombinedDarkTheme}>
                        <AppNavigator />
                    </NavigationContainer>
                </PaperProvider>
            </PreferencesContext.Provider>
        );
    }
}

registerRootComponent(App);


const MyTheme = {
    dark: true,
    colors: {
        primary: StyleConstants.PRIMARY_BLUE_COLOR,
        background: StyleConstants.BACKGROUND,
        card: StyleConstants.CARD,
        text: StyleConstants.TEXT,
        border: StyleConstants.BORDER,
    },
};
