import React from 'react';
import {
    ActivityIndicator,
    NativeSyntheticEvent,
    NativeTouchEvent,
    StyleSheet,
    TouchableHighlight,
    View
} from "react-native";
import {Image} from "react-native-elements";
import {RobotoBoldText, RobotoText} from "components/utils/texts/StyledText";
import {GLOBAL_STYLES} from "style/GlobalStyles";

type Props = {
    title: String;
    author: String;
    year: String;
    isbn: String;
    onPress?: (ev: NativeSyntheticEvent<NativeTouchEvent>) => void;
    children?: React.ReactNode;
}

export const BookListItem: React.FC<Props> = (props: Props) => {
    return (
        <TouchableHighlight onPress={props.onPress}>
            <View style={styles.bookContainer}>
                <Image style={styles.bookImage}
                       source={{uri: `https://www.obalkyknih.cz/api/cover?isbn=${props.isbn}`}}
                       PlaceholderContent={<ActivityIndicator
                           style={GLOBAL_STYLES.indicator}/>
                       }
                />
                <View style={styles.bookInfoContainer}>
                    <View style={styles.bookTextRowContainer}>
                        <RobotoBoldText style={GLOBAL_STYLES.bookHeading}
                                        numberOfLines={1}>{props.title}</RobotoBoldText>
                    </View>
                    <View style={styles.bookTextRowContainer}>
                        <RobotoText style={GLOBAL_STYLES.bookInfo}>Autor:{' '}</RobotoText><RobotoBoldText
                        style={GLOBAL_STYLES.bookInfo} numberOfLines={1}>{props.author}</RobotoBoldText>
                    </View>
                    <View style={styles.bookTextRowContainer}>
                        <RobotoText style={GLOBAL_STYLES.bookInfo}>Rok:{' '}</RobotoText>
                        <RobotoBoldText style={GLOBAL_STYLES.bookInfo}
                                        numberOfLines={1}>{props.year}</RobotoBoldText>
                    </View>
                    <View style={styles.bookTextChildrenContainer}>
                        {props.children}
                    </View>
                </View>
            </View>
        </TouchableHighlight>
    );

}


const styles = StyleSheet.create({
    bookContainer: {
        flexDirection: "row",
        marginLeft: 10,
        marginRight: 10,
    },
    bookImage: {
        height: 145,
        width: 100
    },
    bookInfoContainer: {
        flexDirection: "column",
        marginLeft: 10,
    },
    bookTextRowContainer: {
        flexDirection: "row",
    },
    bookTextChildrenContainer: {
        flexDirection: "row",
        marginTop: 4
    },

});
