import React from 'react';
import {Dimensions, ImageBackground, StyleSheet, TouchableHighlight, View} from "react-native";
import {RobotoBoldText, RobotoText} from "components/utils/texts/StyledText";
import {appColor} from "constants/Colors";
import {useTheme} from "react-native-paper";
import ArrowRightIcon from 'assets/svg/arrowRight.svg';
import {ShortCutEnhancedView} from "./ShortCutEnhancedView";
import {ShortCut} from "../../screens/HomeScreen";
import { TabActions } from '@react-navigation/native';

const {width: WINDOW_WIDTH} = Dimensions.get('window');

type Props = {
    title: String;
    description?: String;
    imagePath: any;
    navigation: any;
    target: any;
    shortCuts: ShortCut[]
    tabBarShortCutTarget?: String;
}

export const CardItem: React.FC<Props> = (props: Props) => {

    const { navigation } = props;
    const tabBarShortCutToAction = TabActions.jumpTo(String(props.tabBarShortCutTarget));
    const theme = useTheme();

    const shortCutEnhancedView = (!props.shortCuts || !props.shortCuts.length) ? null : <ShortCutEnhancedView shortCuts={props.shortCuts} navigation={navigation} target={""}/>
    return (
        <View style={styles.container}>
                <View>
                    <ImageBackground source={props.imagePath} style={styles.cover} imageStyle={{resizeMode: 'cover'}}>
                        {shortCutEnhancedView}
                    </ImageBackground>
                    <TouchableHighlight onPress={() => props.tabBarShortCutTarget ? navigation.dispatch(tabBarShortCutToAction) : navigation.navigate(props.target)}>
                    <View style={[styles.cardBar, {backgroundColor: theme.colors.surface}]}>
                        <View style={{flexDirection: "row"}}>
                            <View style={{flex:6}}>
                                <RobotoBoldText style={[styles.header, {color: theme.colors.text}]} numberOfLines={1}>{props.title}</RobotoBoldText>
                                <RobotoText style={[styles.description, {color: theme.colors.placeholder}]} numberOfLines={1}>{props.description}</RobotoText>
                            </View>
                            <View style={{flex: 1, justifyContent: "center"}}>
                                <ArrowRightIcon height={20} stroke={theme.colors.placeholder} style={{marginLeft: 15}}/>
                            </View>
                        </View>
                    </View>
                    </TouchableHighlight>
                </View>
        </View>
    );
}

const styles = StyleSheet.create({
    container:{
        //flexDirection: "column",
        height: 250,
        width: WINDOW_WIDTH - 36,
        marginTop: 10,
        borderRadius: 20,
        overflow: "hidden",
        backgroundColor: appColor.black
    },
    cover: {
        //flex: 2,
        height: 180,
    },
    cardBar: {
        //flex: 1,
        height: 70,
        backgroundColor: appColor.white,
        padding: 15,
    },
    header: {
        color: appColor.black,
        opacity: 0.85,
        fontSize: 18,
    },
    description: {
        color: appColor.gray,
        marginTop: 3,
        fontSize: 14,
    },
});
