import React from 'react';
import {Dimensions, StyleSheet, View, TouchableWithoutFeedback} from "react-native";
import {Image} from "react-native-elements";
import {RobotoBoldText, RobotoText} from "components/utils/texts/StyledText";
import { useTheme } from 'react-native-paper';
import ActiveCircleIcon from 'assets/svg/circleIcon2.svg';

const {width: WINDOW_WIDTH} = Dimensions.get('window');

type Props = {
    title: String;
    description?: String;
    icon: string;
    selected: boolean;
    callback: any;
}

interface State {
    selected: boolean,
}

export const SettingsIcon = (props): JSX.Element => {
    const theme = useTheme();
    const isSelected = props.selected;

    return (
        <ActiveCircleIcon height={11} stroke={isSelected ? theme.colors.text : theme.colors.background} fill={isSelected ? theme.colors.surface : theme.colors.background}/>
    )
};

export const CardSettingsItem: React.FC<Props> = (props: Props) => {
    const theme = useTheme();

    const [ state, setState ] = React.useState<State>({
        selected: props.selected,
    });

    const calc = (): void => {
        props.callback(state.selected);
    }

    return (
        <TouchableWithoutFeedback onPress={() => [calc(), setState({ selected: !state.selected})]}>
            <View style={[styles.container, {borderColor: state.selected ? theme.colors.text : 'transparent', backgroundColor: state.selected ? 'transparent': theme.colors.surface}]}>
                <View style={[styles.heading]}>
                    <View style={{flex: 3}}>
                        <RobotoBoldText style={{fontSize:14, color: theme.colors.text}} numberOfLines={1}>{props.icon+props.title}</RobotoBoldText>
                    </View>
                    <View style={{flex: 1, alignItems: 'flex-end', marginRight: 14}}>
                        <SettingsIcon selected={state.selected}/>
                    </View>
                </View>
                <RobotoText style={[styles.description, { color: theme.colors.text}]} numberOfLines={2}>{props.description}</RobotoText>
            </View>
        </TouchableWithoutFeedback>
    );
}
const styles = StyleSheet.create({
    container:{
        height: 65,
        width: 141,
        marginLeft: 10,
        marginRight: 10,
        marginTop: 10,
        borderRadius: 5,
        borderWidth: 2,
    },
    heading:{
        flexDirection: "row",
        height: '40%',
        width: '100%',
        marginTop: 5,
        marginLeft: 8,
    },
    description:{
        fontSize: 12,
        marginLeft: 13,
        marginRight: 20,
    }
});
