import React, {useContext} from 'react';
import { TouchableOpacity, StyleSheet, Text } from 'react-native';
import {RobotoBoldText, RobotoText} from "components/utils/texts/StyledText";
import {appColor} from "constants/Colors";
import {useTheme} from "react-native-paper";

type Props = {
    title: String;
    theme?: String;
    size?: String;
    disabled?: boolean;
    buttonStyle?: String;
    textStyle?: String;
    onPress: any;
}
/*
theme: black, white, blue, red, grey
size: large, middle, small
disabled: true, false
*/

const defaultProps = {
    theme: 'black',
    size: 'large',
    disabled: false,
}

export const CustomButton: React.FC<Props> = (props: Props) => {
    const theme = useTheme();

    const {containerStyles, textStyles} = getStyles(props.theme, props.size, props.disabled);

    return (
        <TouchableOpacity onPress={props.onPress} style={[containerStyles, props.buttonStyle, {backgroundColor: theme.colors.text}]} disabled={props.disabled}>
            <RobotoText style={[textStyles, props.textStyle, {color: theme.colors.background}]}>{props.title}</RobotoText>
        </TouchableOpacity>
    );
};

const getStyles = (
    theme,
    size,
    disabled,
) => {
    const containerStyles = [styles.containerDefault];
    const textStyles = [styles.textDefault];

    //theme
    if(theme === 'black'){
        containerStyles.push(styles.containerBlack);
        textStyles.push(styles.textWhite);
    } else if(theme === 'white'){
        containerStyles.push(styles.containerWhite);
        textStyles.push(styles.textBlack);
    } else if(theme === 'blue'){
        containerStyles.push(styles.containerBlue);
        textStyles.push(styles.textWhite);
    } else if(theme === 'red'){
        containerStyles.push(styles.containerRed);
        textStyles.push(styles.textWhite);
    } else if(theme === 'grey'){
        containerStyles.push(styles.containerGrey);
        textStyles.push(styles.textGrey);
    } else {
        containerStyles.push(styles.containerBlack);
        textStyles.push(styles.textWhite);
    }

    //size
    if(size === 'large'){
        containerStyles.push(styles.containerLarge);
        textStyles.push(styles.textLarge);
    } else if(size === 'middle'){
        containerStyles.push(styles.containerMiddle);
        textStyles.push(styles.textMiddle);
    } else if(size === 'small') {
        containerStyles.push(styles.containerSmall);
        textStyles.push(styles.textSmall);
    } else {
        containerStyles.push(styles.containerLarge);
        textStyles.push(styles.textLarge);
    }

    //disabled
    if(disabled){
        containerStyles.push(styles.containerGrey);
        textStyles.push(styles.textGrey);
    }

    return {containerStyles, textStyles};
}

const styles = StyleSheet.create({
    // Container Styles
    containerDefault: {
        display: 'flex',
        height: 50,
        marginTop: 10,
        marginBottom: 10,
        borderRadius: 5,
        justifyContent: 'center',
        alignItems: 'center',

        shadowColor: appColor.black,
        shadowOffset: {
            width: 0,
            height: 2,
        },
        shadowOpacity: 0.5,
        shadowRadius: 2.62,
        elevation: 4,
    },
    containerBlack: {
        backgroundColor: appColor.black,
    },
    containerWhite: {
        backgroundColor: appColor.white,
    },
    containerBlue: {
        backgroundColor: appColor.blue, //missing linear-gradient(188.8deg, #3D639D 3.26%, #343D63 100%);
    },
    containerRed: {
        backgroundColor: appColor.red,
    },
    containerGrey: {
        backgroundColor: appColor.lightGray,
    },
    containerLarge: {
        width: '85%',
    },
    containerMiddle: {
        width: '55%',
    },
    containerSmall: {
        width: '35%',
    },
    // Text Styles
    textDefault: {
        paddingLeft: 10,
        paddingRight: 10,
    },
    textBlack: {
        color: appColor.black,
    },
    textWhite: {
        color: appColor.white,
    },
    textGrey: {
        color: appColor.gray,
    },
    textLarge:{
        fontSize: 16,
    },
    textMiddle:{
        fontSize: 16,
    },
    textSmall:{
        fontSize: 16,
    },
});