import React from 'react';
import {Dimensions, StyleSheet, View, TextInput} from "react-native";
import {RobotoBoldText, RobotoText} from "components/utils/texts/StyledText";
import {appColor} from "constants/Colors";
import {useTheme} from "react-native-paper";

const {width: WINDOW_WIDTH} = Dimensions.get('window');

type Props = {
    label?: String;
    value?: string;
    secureTextEntry?: boolean;
    setState?: any;
    state?: any;
    callback: any;
}

interface State {
    value: string
}

export const CustomInput: React.FC<Props> = (props: Props) => {
    const theme = useTheme()

    const [state, setState] = React.useState<State>({
        value: props.value
    });

    const calc = () => {
        props.callback(state.value);
    }

    return (
        <View style={[styles.container, {backgroundColor: theme.colors.background}]}>
            <RobotoBoldText style={[styles.label, {color: theme.colors.text}]}>{props.label}</RobotoBoldText>
            <TextInput  style={[styles.input, {backgroundColor: theme.colors.surface, color: theme.colors.text}]}
                        secureTextEntry={props.secureTextEntry}
                        pattern={[
                            '^.{4,}$', // min 4 chars - (because of our test / test account)  in future we can add pattern check just by xnameValid[0, 1, 2] ...
                            '(?=.*\\d)', // number required
                        ]}
                        value={state.value}
                        onChangeText={(text) => {
                                setState({value: text})
                                calc();
                            }
                        }
                        //onValidation={xnameValid => props.setState({...props.state, xnameValid})}
                        //onValidation={passwordValid => setState({...state, passwordValid})}
                        //onChangeText={(passwordInput) => setState({...state, password: passwordInput})}
                    />
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        flexDirection: 'column',
        marginBottom: 30,
        width: '85%',
    },
    label: {
        marginBottom: 5,
    },
    input: {
        height: 50,
        width: '100%',
        backgroundColor: appColor.white,
        borderRadius: 5,
        borderWidth: 1,
        borderColor: 'rgba(228, 228, 228, 0.6)',
        paddingLeft: 20,
        color: appColor.black,
    },
});
