import React from "react";
import {StyleSheet, TouchableOpacity, View, Image} from "react-native";
import {RobotoText} from "components/utils/texts/StyledText";
import {RobotoBoldText} from "components/utils/texts/StyledText";
import {getText} from "locales/Locales";
import {useTheme} from "react-native-paper";
import moment from "moment";
import {appColor} from "../../constants/Colors";
import TimeIcon from "assets/svg/timeIcon.svg";

interface Props {
    title: string,
    description: string,
    imagePath: string;
    category: any,
    date: Date,
    contentUrl: string,
    categories: any,
    navigation: any;
    target: any;
}

export const NewsFeedItem: React.FC<Props> = (props: Props) => {

    const {title, description, imagePath, category, date} = props;
    const theme = useTheme();

    const parseDate = (Date): String => {

        const newDate = new window.Date();
        const yesterday = moment(newDate.setDate(newDate.getDate() - 1)).format('MM-DD-YYYY');
        //const dayBeforeYesterday = moment(newDate.setDate(newDate.getDate() - 1)).format('MM-DD-YYYY');
        const newsFeedItemDate = moment(date).format('MM-DD-YYYY');

        if(yesterday == newsFeedItemDate){
            return getText('newsListScreen.yesterday');
        }
        /*else if(dayBeforeYesterday == newsFeedItemDate){
            return getText('newsListScreen.dayBeforeYesterday');
        }*/
        else{
            return moment(Date).format('D.M.YYYY') as String;
        }
    };

    let getCategory = (categoryValue) => {
        let category = props.categories.find(data => data.value === categoryValue);
        if(category) {
            return category;
        }
        else{
            let unhandledCategory = props.categories.find(data => data.value === "");
            unhandledCategory.title = categoryValue;
            return unhandledCategory;
        }
    };

    return (
        <TouchableOpacity onPress={() => props.navigation.navigate(props.target, {
            title: props.title,
            content: props.description,
            imagePath: props.imagePath,
            date: parseDate(props.date),
            categoryTitle: getCategory(props.category).title.toUpperCase(),
            categoryColor: getCategory(props.category).color,
            contentUrl: props.contentUrl
        })}>
            <View style={[styles.container, {backgroundColor: theme.colors.surface}]}>
                <View style={styles.iconView}>
                    <View style={styles.shadow}>
                        <Image source={{uri: imagePath}} style={[styles.icon, {backgroundColor: theme.colors.background}]} />
                    </View>
                </View>
                <View style={styles.infoView}>
                    <View style={{height: 65}}>
                        <RobotoBoldText style={{color: theme.colors.text , fontSize: 14}} numberOfLines={2}>{title}</RobotoBoldText>
                        <RobotoText style={{color: theme.colors.text, fontSize: 12, paddingTop: 5}} numberOfLines={1}>{description}</RobotoText>
                        <View style={{flexDirection: "row", paddingTop: 8}}>
                            <RobotoBoldText style={{color: getCategory(category).color, flex: 2, fontSize: 12}}>{getCategory(category).title.toUpperCase()}</RobotoBoldText>
                            <View style={{flex: 2, flexDirection: "row", opacity: 0.4}}>
                                <TimeIcon style={[styles.timeIcon, {flex: 1}]} height={20} stroke={theme.colors.text}/>
                                <RobotoText style={{color: theme.colors.text, flex: 1, fontSize: 11}}>{parseDate(date)}</RobotoText>
                            </View>
                        </View>
                    </View>
                </View>
            </View>
        </TouchableOpacity>
    );
}

const styles = StyleSheet.create({
    container: {
        flexDirection: "row",
        height: 110,
        borderBottomWidth: 1,
        borderBottomColor: appColor.lightGrayBorder,
        paddingRight: 70,
    },
    iconView: {
        flex: 3,
        justifyContent: 'center',
        alignItems: 'center',
    },
    infoView: {
        flex: 7,
        justifyContent: 'center',
        paddingLeft: 5,
    },
    icon: {
        height: 65,
        width: 65,
        resizeMode : 'cover',
        borderRadius: 10,
    },
    timeIcon: {
        marginRight: 7,
        marginLeft: 5,
        marginTop: -3
    },
    shadow: {
        shadowColor: appColor.black,
        shadowOffset: {
            width: 4,
            height: 10,
        },
        shadowOpacity: 0.2,
        shadowRadius: 10,
        elevation: 4,
    },
});
