import React, {useContext} from 'react';
import {Dimensions, StyleSheet, Switch, TouchableHighlight, TouchableOpacity, View} from "react-native";
import {Image} from "react-native-elements";
import {RobotoBoldText, RobotoText} from "components/utils/texts/StyledText";
import {appColor} from "constants/Colors";
import { useTheme } from 'react-native-paper';
import { PreferencesContext } from 'context/PrefferencesContext';

const {width: WINDOW_WIDTH} = Dimensions.get('window');

type Props = {
    title: String;
    description: String;
    balance: String;
    balanceDescription: String;
    setState: any;
    state: any;
    visible: boolean;
}

export const ProfileCard: React.FC<Props> = (props: Props) => {
    const theme = useTheme();

    return (
        <View style={[styles.container, {backgroundColor: theme.colors.surface}]}>
            <TouchableHighlight underlayColor={theme.colors.surface} onPress={() => props.setState({...props.state, modalVisible: props.visible})}>
                <View>
                    <View style={{flexDirection: "row"}}>
                        <View style={styles.userIcon}>
                            <Image source={require("assets/userIcon.png")} style={{height: 45, borderRadius: 10}} resizeMode="contain"/>
                        </View>
                        <View style={{flex:6}}>
                            <RobotoBoldText style={[styles.header, {color: theme.colors.text}]}>{props.title}</RobotoBoldText>
                            <RobotoText style={[styles.description, {color: theme.colors.placeholder}]}>{props.description}</RobotoText>
                        </View>
                        <View style={{height: '100%', width: 1, backgroundColor: appColor.lightGrayBorder}}/>
                        <View style={{flex:3, flexDirection: "column"}}>
                            <View style={{flex:1, flexDirection: "row", alignItems: "flex-end",justifyContent: "center"}}>
                                    <RobotoBoldText style={[styles.balance, {color: theme.colors.text}]}>{props.balance}</RobotoBoldText>
                            </View>
                            <View style={{flex:1, flexDirection: "row", alignItems: "flex-start",justifyContent: "center"}}>
                                <RobotoText style={[styles.balanceDescription, {color: theme.colors.text}]}>{props.balanceDescription}</RobotoText>
                            </View>
                        </View>
                    </View>
                </View>
            </TouchableHighlight>
        </View>
    );
}

const styles = StyleSheet.create({
    container:{
        width: WINDOW_WIDTH - 36,
        marginTop: 30,
        marginBottom: 10,
        borderRadius: 20,
        overflow: "hidden"
    },
    userIcon: {
        flex:2,
        paddingTop: 15,
        paddingBottom: 15,
    },
    header: {
        color: appColor.black,
        opacity: 0.85,
        fontSize: 18,
        marginLeft: 5,
        paddingTop: 17,
    },
    description: {
        color: appColor.gray,
        marginTop: 3,
        fontSize: 14,
        marginBottom: 2,
        marginLeft: 5,
    },
    balance:{
        color: appColor.black,
        fontSize: 18,
    },
    balanceDescription: {
        color: appColor.gray,
        fontSize: 13,
        marginTop: 3,
    },
});
