import React from "react";
import {StyleSheet, View, ScrollView} from "react-native";
import {useTheme} from "react-native-paper";
import {appColor} from "../../constants/Colors";
import {TabFilterItem} from "components/library/TabFilterItem";

interface Props {
    filterItems: any,
    callback: any,
}

interface State {
    selectedFilterItem: string,
}

export const TabFilter: React.FC<Props> = (props: Props) => {
    const theme = useTheme();

    const [ state, setState ] = React.useState<State>({
        selectedFilterItem: 'ALL'
    });

    const getSelectedItemKey = (key) => {
        setState({ selectedFilterItem: key });
        props.callback(props.filterItems.find( data => data.key === key).value);
    }

    return (
        <View style={[styles.container, {backgroundColor: theme.colors.background}]}>
            <ScrollView horizontal={true} showsHorizontalScrollIndicator={false} contentContainerStyle={styles.scrollViewPanelContainer}>
                {props.filterItems.map((filterItem, index) =>
                    <TabFilterItem
                        key={index}
                        itemKey={filterItem.key}
                        itemTitle={filterItem.title}
                        itemValue={filterItem.value}
                        callback={getSelectedItemKey.bind(this)}
                        selectedItem={filterItem.key == state.selectedFilterItem}
                    />
                )}
            </ScrollView>
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        borderTopWidth: 1,
        borderTopColor: appColor.lightGrayBorder,
        borderBottomWidth: 1,
        borderBottomColor: appColor.lightGrayBorder,
        paddingLeft: 10
    },
    scrollViewPanelContainer: {
        justifyContent: 'space-between',
        paddingVertical: 15
    },
    filterItem: {
        fontSize: 14,
        paddingLeft: 10,
        paddingRight: 10,
        color: appColor.gray
    },
});
