import React from "react";
import {StyleSheet, TouchableWithoutFeedback, View} from "react-native";
import {RobotoBoldText, RobotoText} from "components/utils/texts/StyledText";
import {appColor} from "../../constants/Colors";

interface State {
    selected: boolean,
}

interface Props {
    itemKey: string,
    itemTitle: string,
    itemValue: string,
    callback: any,
    selectedItem: boolean,
}

export const TabFilterItem: React.FC<Props> = (props: Props) => {

    const [ state, setState ] = React.useState<State>({
        selected: false
    });

    const calc = (): void => {
        props.callback(props.itemKey);
    }

    return (
        <TouchableWithoutFeedback onPress={() => [calc(),setState({ selected: !state.selected})]} key={props.itemKey}>
            <View style={{alignItems: 'center'}}>
                <RobotoBoldText style={[styles.filterItem, props.selectedItem ? styles.itemSelected : styles.itemUnselected]} key={props.itemKey}>
                    {props.itemTitle}
                </RobotoBoldText>
                <View style={[styles.selectedIndicator, props.selectedItem ? null : styles.inActiveSelectedIndicator]}/>
            </View>
        </TouchableWithoutFeedback>
    );
}

const styles = StyleSheet.create({
    filterItem: {
        fontSize: 14,
        paddingLeft: 10,
        paddingRight: 10,

    },
    itemSelected:{
        color: appColor.blue
    },
    itemUnselected:{
        color: appColor.gray
    },
    selectedIndicator:{
        position: 'relative',
        top: 16,
        height: 3,
        width: '80%',
        borderRadius: 20,
        backgroundColor: appColor.blue,
    },
    inActiveSelectedIndicator: {
        backgroundColor: 'transparent',
    }
});
