import React from 'react';
import {Linking, StyleSheet, TouchableOpacity, View} from "react-native";
import {useTheme} from "react-native-paper";
import ArrowRightIcon from 'assets/svg/arrowRightIcon.svg';
import {RobotoBoldText} from "../utils/texts/StyledText";

type Props = {
    textColor: string,
    icon: JSX.Element
    target: string
    label: string
}

export const TouchableShortCutButton: React.FC<Props> = (props: Props) => {
    const theme = useTheme();

    return (
            <TouchableOpacity onPress={() => Linking.openURL(props.target)}>
                <View style={[styles.container, {backgroundColor: theme.colors.surface}]}>
                    <View style={[styles.wrapper, {backgroundColor: theme.colors.surface}]}>
                        <View style={[styles.iconStyle, {backgroundColor: props.textColor}]}>
                        {props.icon}
                        </View>
                        <ArrowRightIcon height={25} stroke={theme.colors.placeholder} style={styles.arrowIcon}/>
                    </View>
                    <View style={styles.bottomContainer}>
                        <RobotoBoldText style={{color: props.textColor}}>{props.label}</RobotoBoldText>
                    </View>
                </View>
            </TouchableOpacity>
    );
}

const styles = StyleSheet.create({
    container: {
        borderRadius: 8,
        marginTop: 50,
        padding: 10,
        marginLeft: 20,
        width: 100,
        height: 80,
        flexDirection: "column"
    },
    wrapper: {
        flexDirection: "row",
        alignSelf: "auto"
    },
    bottomContainer: {
        position: 'absolute',
        bottom: 10,
        left: 8
    },
    scrollViewPanelContainer: {
        justifyContent: 'space-between',
        paddingVertical: 15,
        flexGrow : 1
    },
    arrowIcon: {
        position: 'absolute',
        right: 0,
        top: -5
    },
    iconStyle: {
       padding: 5,
        borderRadius: 8
    }
});


