import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import {TouchableOpacity, View, ViewPropTypes} from 'react-native';

import styles from 'components/pagination/Styles';


interface Props {
  scrollToIndex: any
  data: any,
  paginationIndex: number,
  paginationActiveColor: string,
  paginationDefaultColor: string,
  paginationStyle: any,
  paginationStyleItem: any,
}

export default class Pagination extends PureComponent<Props> {
  static propTypes = {
    scrollToIndex: PropTypes.func.isRequired,
    data: PropTypes.array,
    paginationIndex: PropTypes.number,
    paginationActiveColor: PropTypes.string,
    paginationDefaultColor: PropTypes.string,
    paginationStyle: ViewPropTypes.style,
    paginationStyleItem: ViewPropTypes.style,
  };

  static defaultProps = {
    data: [],
    paginationIndex: 2,
    paginationActiveColor: '#000000',
    paginationDefaultColor: 'transparent',
    paginationStyle: {flexDirection: 'row', justifyContent: 'center'},
    paginationStyleItem: {
      width: 12,
      height: 12,
      opacity: 0.45,
      borderStyle: "solid",
      borderRadius: 6,
      borderWidth: 2,
      borderColor: "#000000",
     }
  };

  render() {
    const {
      data,
      paginationIndex,
      scrollToIndex,
      paginationDefaultColor,
      paginationActiveColor,
      paginationStyle,
      paginationStyleItem,
    } = this.props;
    return (
      <View style={[paginationStyle]}>
        {data.map((_, index) => (
          <TouchableOpacity
            style={[
              styles.pagination,
              paginationStyleItem,
              paginationIndex === index
                ? { backgroundColor: paginationActiveColor }
                : { backgroundColor: paginationDefaultColor },
            ]}
            key={index}
            onPress={() => scrollToIndex(index)}
          />
        ))}
      </View>
    );
  }
}
