import React, {useState} from "react";
import {StyleSheet, TouchableOpacity, View} from "react-native";
import { RobotoText} from "components/utils/texts/StyledText";
import CircleIcon from "../../../assets/svg/circleIcon.svg";
import {useTheme} from "react-native-paper";
import {ProviderMenu} from "./model/FoodPoint";

interface Props {
    filters: string[]
    label: string,
    active: boolean,
}

export const FoodProviderFilterItem: React.FC<Props> = (props: Props) => {
   const [active, setActive] = useState<boolean>(false);

    const {label} = props;
    const theme = useTheme();

    return (
        <TouchableOpacity onPress={() => console.log(props.label)}>
            <View style={[styles.container, {backgroundColor: theme.colors.surface, borderColor: theme.colors.disabled}]}>
                <RobotoText style={[styles.text, {color: theme.colors.text}]}>{label}</RobotoText>
                <CircleIcon style={styles.icon} height={20} fill={getSvgColor(props.filters, props.label)} stroke={getSvgColor(props.filters, props.label)}/>
            </View>
        </TouchableOpacity>
    );
}

function getSvgColor(filters: string[], label: string) {
    const isFiltered = filters.includes(label);
    return isFiltered ? "#27AE60" : "#AE2727";
}

const styles = StyleSheet.create({
    container: {
        height: 30,
        padding: 7,
        marginLeft: 15,
        borderWidth: 1,
        borderRadius: 6,
        flexDirection: 'row',
        alignSelf: 'flex-start'
    },
    text: {
        marginLeft: 5
    },
    icon: {
        marginRight: 7,
        marginLeft: 5,
        marginTop: -2
    }
});
