import {useEffect, useState} from "react";
import {FoodPoint, ProviderMenu} from "../components/model/FoodPoint";

const BASE_URL = 'https://appbackend.pef.czu.cz/foodpoint';

const FOOD_PROVIDERS_URL = BASE_URL + '/getProviders';
const FOOD_DAILY_OFFERS_ALL = BASE_URL + '/getMenuByDate?days=3&range=9000';
const FOOD_DAILY_OFFERS_DAILY = BASE_URL + '/getMenuByDate?days=3&range=3';

export const useFetchFoodProviders = () => {
    const [loading, setLoading] = useState(true);
    const [foodProviders, setFoodProviders] = useState([]);

    useEffect(() => {
        const fetchData = async () => {
            const response = await fetch(FOOD_PROVIDERS_URL);
            const data = await response.json();

            setFoodProviders(data);
            setLoading(false);
        };

        fetchData();
    }, []);

    return { loading, foodProviders };
};

export const useFetchFoodOffers = (dailyMenu: boolean, filters: string[]) => {
    const [loading, setLoading] = useState(true);
    const [foodOffers, setFoodOffers] = useState<ProviderMenu[]>();
    const [foodProviders, setFoodProviders] = useState<string[]>();

    const targetUrl = dailyMenu ? FOOD_DAILY_OFFERS_DAILY : FOOD_DAILY_OFFERS_ALL;

    useEffect(() => {
        const fetchData = async () => {
            const response = await fetch(targetUrl);
            const data: FoodPoint[] = await response.json();

            const providerMenu = data[0].ProviderMenu.map(s => s);
            const foodProviders = data[0].ProviderMenu.map(s => s.Provider);

            const filtered: ProviderMenu[] = providerMenu.filter(function (el) {
                return filters.includes(el.Provider);
            });

            setFoodOffers(filtered);
            setFoodProviders(foodProviders);
            setLoading(false);
        };

        fetchData();
    }, []);

    return { loading, foodOffers, foodProviders };
};

export const filterContent = () => {

    return;
};


export const useActiveFilters = (toggledItem: string) => {
    const [activeFilters, setActiveFilters] = useState<string[]>();

    if(activeFilters.includes(toggledItem)) {
        const index = activeFilters.indexOf(toggledItem);
        const splicedArray = activeFilters.splice(index, 1);
        setActiveFilters(splicedArray)

    } else {
        activeFilters.push(toggledItem)
        setActiveFilters(activeFilters)
    }

    return { activeFilters };

}