import * as React from "react";
import {ScrollView, StyleSheet, View, ActivityIndicator, RefreshControl} from "react-native";
import {TabFilter} from "components/library/TabFilter";
import {useTheme} from "react-native-paper";
import {NewsListScreens} from "navigation/Screens";
import {getText} from "locales/Locales";

import {appColor} from "constants/Colors";
import {useNavigation} from "@react-navigation/native";
import {StackNavigationProp} from "@react-navigation/stack";
import {useState} from "react";
import {useJobOffers} from "./service/JobsPefService";
import {JobsOfferItem} from "./components/JobsOfferItem";

interface JobType {
    key: string;
    title: string;
    value: string;
    color: any;
}

interface Links {
    self: string;
    firma: string;
}

export interface JobOfferData {
    id: number;
    nazev: string;
    primarni_forma: string;
    charakteristika: string;
    aktualnost: string;
    firma_logo: string;
    date_created_cs: string;
    platnost_od_cs: string;
    firma_id: string;
    firma_nazev: string;
    favourited_by_auth: boolean;
    links: Links
}

export const JobsPefScreen: React.FC = () => {
    const theme = useTheme();
    const navigation = useNavigation<StackNavigationProp<any>>();
    const [filterCategory, setFilterCategory] = useState<string>("");
    const {jobOffers, loading} = useJobOffers(filterCategory);

    let jobCategories: JobType[] = [
        { key: "ALL", title: getText('jobsPefScreen.filter.all'), value: "" , color: appColor.black},
        { key: "fulltime", title: getText('jobsPefScreen.filter.fullTime'), value: "prace_plny", color: appColor.red},
        { key: "parttime", title: getText('jobsPefScreen.filter.partTime'), value: "prace_castecny", color: appColor.blue},
        { key: "trainee", title: getText('jobsPefScreen.filter.trainee'), value: "trainee", color: '#219653' },
        { key: "internship", title: getText('jobsPefScreen.filter.internship'), value: "staz", color: '#219653' },
    ];

    const getDataByCategory = (value) => {
        setFilterCategory(value)
    }

    const onRefresh = () => {
        console.log("refresh");
        //TODO: Finish refreshing
    }

    return (
        <View style={styles.container}>
            <TabFilter
                filterItems={jobCategories}
                callback={getDataByCategory.bind(this)}
            />
            <View style={[styles.container, loading && {justifyContent: 'center'}, {backgroundColor: theme.colors.surface}]}>
                {loading && <ActivityIndicator size="large" color={theme.colors.text}/>}
                {!loading && <ScrollView contentContainerStyle={null}
                                         refreshControl={
                                             <RefreshControl
                                                 refreshing={loading}
                                                 onRefresh={onRefresh}
                                             />}>
                    {loading ? <ActivityIndicator/> : jobOffers.map(jobOffer => {
                        return(
                            <JobsOfferItem
                                key={jobOffer.id}
                                title={jobOffer.nazev}
                                description={jobOffer.charakteristika}
                                imagePath={jobOffer.firma_logo}
                                category={jobOffer.firma_nazev}
                                date={jobOffer.date_created_cs}
                                contentUrl={jobOffer.links.self}
                                categories={jobCategories}
                                navigation={navigation}
                                target={jobOffer.links.self}
                            />
                        );
                    })
                    }
                </ScrollView>}
            </View>
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        height: '97%',
        width: '100%',
    },
});

export default JobsPefScreen;