import React from "react";
import {StyleSheet, TouchableOpacity, View, Image, Linking} from "react-native";
import {RobotoText} from "components/utils/texts/StyledText";
import {RobotoBoldText} from "components/utils/texts/StyledText";
import {useTheme} from "react-native-paper";
import {appColor} from "../../../constants/Colors";
import TimeIcon from "assets/svg/timeIcon.svg";

interface Props {
    title: string,
    description: string,
    imagePath: string;
    category: any,
    date: Date,
    contentUrl: string,
    categories: any,
    navigation: any;
    target: any;
}

export const JobsOfferItem: React.FC<Props> = (props: Props) => {

    const {title, description, imagePath, category, date} = props;
    const theme = useTheme();

    let getCategory = (categoryValue) => {
        let category = props.categories.find(data => data.value === categoryValue);
        if(category) {
            return category;
        }
        else{
            let unhandledCategory = props.categories.find(data => data.value === "");
            unhandledCategory.title = categoryValue;
            return unhandledCategory;
        }
    };

    return (
        <TouchableOpacity onPress={() => Linking.openURL(props.target)}>
            <View style={[styles.container, {backgroundColor: theme.colors.surface}]}>
                <View style={styles.iconView}>
                    <View style={styles.shadow}>
                        <Image source={{uri: imagePath}} style={[styles.icon, {backgroundColor: theme.colors.background}]} />
                    </View>
                </View>
                <View style={styles.infoView}>
                    <View>
                        <RobotoBoldText style={{color: theme.colors.text , fontSize: 14}} numberOfLines={2}>{title}</RobotoBoldText>
                        <RobotoText style={{color: theme.colors.text, fontSize: 12, paddingTop: 5}} numberOfLines={15}>{description}</RobotoText>
                        <View style={{flexDirection: "row", paddingTop: 8}}>
                            <RobotoBoldText style={{color: theme.colors.text, flex: 2, fontSize: 12}}>{getCategory(category).title.toUpperCase()}</RobotoBoldText>
                            <View style={{flex: 2, flexDirection: "row", opacity: 0.4}}>
                                <TimeIcon style={[styles.timeIcon, {flex: 1}]} height={20} stroke={theme.colors.text}/>
                                <RobotoBoldText style={{color: theme.colors.text, flex: 1, fontSize: 11}}>{date}</RobotoBoldText>
                            </View>
                        </View>
                    </View>
                </View>
            </View>
        </TouchableOpacity>
    );
}

const styles = StyleSheet.create({
    container: {
        flexDirection: "row",
        flex: 1,
        height: 'auto',
        padding: 35,
        borderBottomWidth: 1,
        borderBottomColor: appColor.lightGrayBorder
    },
    iconView: {
        flex: 3
    },
    infoView: {
        flex: 7,
        paddingLeft: 5,
    },
    icon: {
        height: 65,
        width: 65,
        borderRadius: 10,
        resizeMode: "contain"
    },
    timeIcon: {
        marginRight: 7,
        marginLeft: 5,
        marginTop: -3
    },
    shadow: {
        shadowColor: appColor.black,
        shadowOffset: {
            width: 4,
            height: 10,
        },
        shadowOpacity: 0.2,
        shadowRadius: 10,
        elevation: 4,
    },
});
