import React from "react";
import { createStackNavigator } from "@react-navigation/stack";
import {useTheme} from "react-native-paper";
import {getText} from "../locales/Locales";

import {AppModules, NewsListScreens} from "navigation/Screens";
import FirstStepsScreen from "screens/FirstStepsScreen";
import {LibraryTabStack} from "screens/library/LibraryTabStack";
import {LibraryLoginScreen} from "screens/library/LibraryLoginScreen";
import NavigationScreen from "screens/NavigationScreen";
import {FoodPointScreen} from "../feature/foodpoint/FoodPointScreen";
import LinksScreen from "screens/LinksScreen";
import NewsListScreen from "screens/NewsFeedScreen";
import {HomeScreen} from "screens/HomeScreen";
import NewsFeedItemScreen from "screens/NewsFeedItemScreen";
import JobsPefScreen from "../feature/jobspef/JobsPefScreen";

const Stack = createStackNavigator();


const HomeScreenNavigator = () => {
    const foodNav = foodPointNavigationOptions();

    return (
        <Stack.Navigator screenOptions={homeScreenOptions}>
            <Stack.Screen name={AppModules.HOME} component={HomeScreen}/>
            <Stack.Screen name={AppModules.FIRST_STEPS} component={FirstStepsScreen}/>
            <Stack.Screen name={AppModules.FOODPOINT} component={FoodPointScreen} options={foodNav}/>
            <Stack.Screen name={AppModules.JOBSPEF} component={JobsPefScreen} options={foodNav}/>
            <Stack.Screen name={AppModules.LIBRARY} component={LibraryTabStack}/>
            <Stack.Screen name={AppModules.LIBRARY_LOGIN} component={LibraryLoginScreen}/>
            <Stack.Screen name={AppModules.NAVIGATION} component={NavigationScreen}/>
            <Stack.Screen name={AppModules.LINKS} component={LinksScreen}/>
        </Stack.Navigator>
    );
};

const NavigationStackNavigator = () => {
    const theme = useTheme();

    return (
        <Stack.Navigator screenOptions={{
            headerShown: true,
            headerStyle: {
                backgroundColor: theme.colors.surface,
                shadowRadius: 0,
                shadowOffset: {
                    height: 0,
                },
            },
            headerTintColor: theme.colors.text,
            headerBackTitle: theme.colors.text
        }}>
            <Stack.Screen name={AppModules.NAVIGATION} component={NavigationScreen} options={{headerTitle: getText("homeScreen.navigationCard.header")}} />
        </Stack.Navigator>
    );
};

const LibraryStackNavigator = () => {
    return (
        <Stack.Navigator screenOptions={homeScreenOptions}>
            <Stack.Screen name={AppModules.LIBRARY} component={LibraryLoginScreen} />
        </Stack.Navigator>
    );
};

const NewsStackNavigator = () => {
    const theme = useTheme();

    return (
        <Stack.Navigator screenOptions={{
            headerShown: true,
            headerStyle: {
                backgroundColor: theme.colors.surface,
                shadowRadius: 0,
                shadowOffset: {
                    height: 0,
                },
            },
            headerTintColor: theme.colors.text,
            headerBackTitle: theme.colors.text
        }}>
            <Stack.Screen name={NewsListScreens.NEWS} component={NewsListScreen} options={{headerTitle: getText("newsListScreen.header")}}/>
            <Stack.Screen name={NewsListScreens.DETAIL} component={NewsFeedItemScreen} options={{headerShown: false}}/>
        </Stack.Navigator>
    );
};

const ProfileStackNavigator = () => {
    return (
        <Stack.Navigator screenOptions={homeScreenOptions}>
            <Stack.Screen name={AppModules.LINKS} component={LinksScreen} />
        </Stack.Navigator>
    );
};

const FoodPointStackNavigator = () => {
    return (
        <Stack.Navigator screenOptions={foodPointScreenOptions}>
            <Stack.Screen name={AppModules.FOODPOINT} component={FoodPointScreen} />
        </Stack.Navigator>
    );
};
export { HomeScreenNavigator, NavigationStackNavigator, LibraryStackNavigator, NewsStackNavigator, ProfileStackNavigator, FoodPointStackNavigator };

const homeScreenOptions = {
    headerShown: false
};

const foodPointNavigationOptions = () => {
    const theme = useTheme();

    return (foodPointScreenOptions = {
        headerShown: true,
        headerStyle: {
            backgroundColor: theme.colors.background,
        },
        headerTintColor: theme.colors.text,
        headerBackTitle: "Back",
    });
};
