import React from 'react';
import { createBottomTabNavigator } from '@react-navigation/bottom-tabs';
import {
    Image,
    View,
    StyleSheet,
} from "react-native";
import {
    HomeScreenNavigator,
    NavigationStackNavigator,
    LibraryStackNavigator,
    NewsStackNavigator,
    ProfileStackNavigator,
} from './StackNavigator'
import {AppModules} from "navigation/Screens";
import {useTheme} from "react-native-paper";
import SovaAvatar from "assets/svg/sovaAvatar.svg";

const Tab = createBottomTabNavigator();

const BottomTabNavigator = () => {
    const theme = useTheme();

    return (
        <Tab.Navigator
            screenOptions={({route}) => ({
                tabBarIcon: ({ focused, color, size }) => {
                    let iconName;
                    if (route.name === AppModules.HOME) {
                        if(iconName = focused) {
                            return  <View>
                                <View style={[styles.viewStyle, {backgroundColor: theme.colors.text}]}/>
                                <Image source={require("assets/boltIcon.png")} style={[styles.iconStyle, {tintColor: theme.colors.text}]} resizeMode="contain"/>
                            </View>
                        }
                        else {
                            return  <View>
                                <View style={[styles.viewStyle, styles.unselectedView]}/>
                                <Image source={require("assets/unselectedBoltIcon.png")} style={[styles.iconStyle, {tintColor: theme.colors.placeholder}]} resizeMode="contain"/>
                            </View>
                        }
                    }
                    else if (route.name === AppModules.NAVIGATION) {
                        if(iconName = focused) {
                            return <View>
                                <View style={[styles.viewStyle, {backgroundColor: theme.colors.text}]}/>
                                <Image source={require("assets/mapIcon.png")} style={[styles.iconStyle, {tintColor: theme.colors.text}]} resizeMode="contain"/>
                            </View>
                        }
                        else {
                            return  <View>
                                <View style={[styles.viewStyle, styles.unselectedView]}/>
                                <Image source={require("assets/unselectedMapIcon.png")} style={[styles.iconStyle, {tintColor: theme.colors.placeholder}]} resizeMode="contain"/>
                            </View>
                        }
                    }
                    else if (route.name === AppModules.LIBRARY) {
                        if(iconName = focused) {
                            return  <View>
                                <View style={[styles.viewStyle, {backgroundColor: theme.colors.text}]}/>
                                <Image source={require("assets/bookIcon.png")} style={[styles.iconStyle, {tintColor: theme.colors.text}]} resizeMode="contain"/>
                            </View>
                        }
                        else {
                            return  <View>
                                <View style={[styles.viewStyle, styles.unselectedView]}/>
                                <Image source={require("assets/unselectedBookIcon.png")} style={[styles.iconStyle, {tintColor: theme.colors.placeholder}]} resizeMode="contain"/>
                            </View>
                        }
                    }
                    else if (route.name === AppModules.NEWS) {
                        if(iconName = focused) {
                            return  <View>
                                <View style={[styles.viewStyle, {backgroundColor: theme.colors.text}]}/>
                                <Image source={require("assets/newsIcon.png")} style={[styles.iconStyle, {tintColor: theme.colors.text}]} resizeMode="contain"/>
                            </View>
                        }
                        else {
                            return  <View>
                                <View style={[styles.viewStyle, styles.unselectedView]}/>
                                <Image source={require("assets/unselectedNewsIcon.png")} style={[styles.iconStyle, {tintColor: theme.colors.placeholder}]} resizeMode="contain"/>
                            </View>
                        }
                    }
                    else if (route.name === AppModules.LINKS) {
                        if(iconName = focused) {
                            return  <View>
                                <View style={[styles.viewStyle, {backgroundColor: theme.colors.text}]}/>
                                <SovaAvatar height={25} stroke={theme.colors.text} style={styles.iconStyle}/>
                            </View>
                        }
                        else {
                            return <View>
                                <View style={[styles.viewStyle, styles.unselectedView]}/>
                                <SovaAvatar height={25} stroke={theme.colors.placeholder} style={styles.iconStyle}/>
                            </View>
                        }
                    }
                }
            })}

            tabBarOptions={{
                showLabel: false,
                style:{
                    backgroundColor: theme.colors.background,
                    borderTopWidth: 0,
                },
            }}>
            <Tab.Screen name={AppModules.HOME}
                        component={HomeScreenNavigator}
                        options={({ route }) => ({
                            tabBarVisible: getTabBarVisibility(route)
                        })}
            />
            <Tab.Screen name={AppModules.NAVIGATION} component={NavigationStackNavigator} />
            <Tab.Screen name={AppModules.LIBRARY} component={LibraryStackNavigator} />
            <Tab.Screen name={AppModules.NEWS} component={NewsStackNavigator} />
            <Tab.Screen name={AppModules.LINKS} component={ProfileStackNavigator} />
        </Tab.Navigator>
    );
}

const getTabBarVisibility = (route) => {
    const routeName = route.state ? route.state.routes[route.state.index].name : '';

    return routeName !== AppModules.FOODPOINT;
}

const styles = StyleSheet.create({
    iconStyle: {
        height: 25,
        width: 25,
        marginTop: 11,
        marginLeft: 8,
    },
    viewStyle: {
        position: 'relative',
        top: -5,
        height: 3,
        width: 41,
        borderRadius: 20,
    },
    unselectedView: {
        backgroundColor: 'transparent',
    }
});

export default BottomTabNavigator;