import React from 'react';
import {AsyncStorage, FlatList, StyleSheet, View} from 'react-native';
import axios from "axios";
import {ListItem} from "react-native-elements";

interface Item {
  id: any,
  name: any,
  code: any
}

export default class LinksScreen extends React.Component<Item, any> {
  static navigationOptions = {
    title: 'Subjects',
  };

  constructor(props) {
    super(props);
    this.state = {
      isLoading: true,
      subjects: null
    }
  }

  async componentDidMount() {
    return axios.get('http://wcavp-media-ws.czu.cz/api//Studies/ListStudentSubjects', {headers: {'Access-Token': await AsyncStorage.getItem('access-token')}})
        .then((response) => {
          this.setState({
            isLoading: false,
            subjects: response.data,
          }, function () {

          });

        })
        .catch((error) => {
          console.error(error);
        });
  }

  clickEventListener = (item) => {
    alert("Subject selected: " + item.name)
  };

  render() {
    return (
        <View style={styles.container}>
          <FlatList
              style={styles.tasks}
              data={this.state.subjects}
              keyExtractor= {(item: Item) => {
                return item.id;
              }}
              renderItem={({ item: Item }) => <ListItem title={Item.name} />}/>
        </View>
    );
  }
}

const styles = StyleSheet.create({
  container:{
    flex:1,
    marginTop:20,
    backgroundColor:"#eeeeee"
  },
  tasks:{
    flex:1,
  },
  cardContent: {
    marginLeft:20,
    marginTop:10,
  },
  image:{
    width:25,
    height:25,
  },

  card:{
    shadowColor: '#00000021',
    shadowOffset: {
      width: 0,
      height: 6,
    },
    shadowOpacity: 0.37,
    shadowRadius: 7.49,
    elevation: 12,

    marginVertical: 10,
    marginHorizontal:20,
    backgroundColor:"white",
    flexBasis: '46%',
    padding: 10,
    flexDirection:'row',
    flexWrap: 'wrap',
    borderLeftWidth:6,
  },

  description:{
    fontSize:18,
    flex:1,
    color:"#008080",
    fontWeight:'bold',
  },
  code:{
    fontSize:14,
    flex:1,
    color:"#696969",
    marginTop:5
  },
});
