import React from 'react';
import {Dimensions, Image, ScrollView, StyleSheet, Text, TouchableOpacity, View} from 'react-native';
import TextInput from "components/uiComponents/Input";
import {RobotoBoldText} from "components/utils/texts/StyledText";
import SwiperFlatList from 'react-native-swiper-flatlist';
import Pagination from 'components/pagination/Pagination';
import {LoginScreens} from "navigation/Screens";
import {useNavigation} from "@react-navigation/native";
import {StackNavigationProp} from "@react-navigation/stack";
import {CustomButton} from "components/library/CustomButton";
import {appColor} from "constants/Colors";

const cards = [
    {
        text: 'Card One',
        name: 'One',
        image: require('assets/photoPhone.png')
    },
    {
        text: 'Card Two',
        name: 'Two',
        image: require('assets/photoPhone.png')
    },
    {
        text: 'Card Three',
        name: 'Three',
        image: require('assets/photoPhone.png')
    }];

interface State {
    xnameValid: boolean,
    passwordValid: boolean
    xname: string
    password: string
}

export const LoginScreen: React.FC<void> = () => {

    const navigation = useNavigation<StackNavigationProp<any>>();


    const [state, setState] = React.useState<State>({
        xname: "",
        password: "",
        xnameValid: null,
        passwordValid: null
    });

    const signInAsync = async () => {
        //todo fix
        // if(state.xnameValid[0] && state.passwordValid[0]) {
        //     axios.post('http://wcavp-media-ws.czu.cz/api/Auth/Login', {
        //         username: state.xname.toLowerCase(),
        //         password: state.password
        //     })
        //         .then(function (response) {
        //             // User token -> unchangable
        //             // Session token -> duration ??
        //             if(response.data && JSON.stringify(response.headers["access-token"])) {
        //                 AsyncStorage.setItem("user-token", response.data);
        //                 AsyncStorage.setItem("access-token", response.headers["access-token"]);
        //
        //                 navigation.replace(LoginScreens.APP);
        //             } else {
        //                 alert("Please enter correct credentials");
        //             }
        //         })
        //         .catch(function (error) {
        //             // TODO: Add
        //             console.log(error)
        //         });
        // }
        navigation.replace(LoginScreens.APP);
    };

    return (
        <View style={{flex: 1, backgroundColor: '#225ED9'}}>
            <View style={styles.container}>
                <View style={{flex: 1, alignItems: 'center', marginTop: 70}}>
                    <Image source={require('assets/logo.png')}/>
                </View>
                <View style={{flex: 3, backgroundColor: '#225ED9'}}>
                    <SwiperFlatList
                        autoplay={false}
                        autoplayDelay={2}
                        autoplayDirection={false}
                        autoplayLoop={true}
                        index={0}
                        showPagination
                        PaginationComponent={Pagination}>
                        <View style={[styles.child, {backgroundColor: '#225ED9'}]}>
                            <Image source={require('assets/photoPhone.png')}/>
                            <RobotoBoldText style={styles.text}>UEP pod kontrolou</RobotoBoldText>
                        </View>
                        <View style={[styles.child, {backgroundColor: '#225ed9'}]}>
                            <Image source={require('assets/photoPhone.png')}/>
                            <Text style={styles.text}>2</Text>
                        </View>
                        <View style={[styles.child, {backgroundColor: '#225ED9'}]}>
                            <Image source={require('assets/photoPhone.png')}/>
                            <Text style={styles.text}>3</Text>
                        </View>
                        <View style={[styles.child, {backgroundColor: '#225ED9'}]}>
                            <Image source={require('assets/photoPhone.png')}/>
                            <Text style={styles.text}>5</Text>
                        </View>
                    </SwiperFlatList>
                </View>
                <View style={{flex: 3}}/>
                <View style={{
                    backgroundColor: appColor.white,
                    width: '100%',
                    justifyContent: 'center',
                    alignItems: 'center',
                    flex: 5,
                    borderTopLeftRadius: 20,
                    borderTopRightRadius: 20,
                }}>
                    <View style={styles.customInputContainer}>
                        <RobotoBoldText style={styles.customInputLabel}>X-Name</RobotoBoldText>
                        <TextInput style={styles.customInput}
                               pattern={[
                                   '^.{4,}$', // min 4 chars - (because of our test / test account)  in future we can add pattern check just by xnameValid[0, 1, 2] ...
                                   '(?=.*\\d)', // number required
                               ]}
                               onValidation={xnameValid => setState({...state, xnameValid})}
                               onChangeText={(xnameInput) => setState({...state, xname: xnameInput})}/>
                    </View>
                    <View style={styles.customInputContainer}>
                        <RobotoBoldText style={styles.customInputLabel}>Heslo</RobotoBoldText>
                        <TextInput style={styles.customInput}
                               secureTextEntry={true}
                               pattern={[
                                   '^.{4,}$', // min 4 chars
                                   '(?=.*\\d)', // number required
                               ]}
                               onValidation={passwordValid => setState({...state, passwordValid})}
                               onChangeText={(passwordInput) => setState({...state, password: passwordInput})}/>
                    </View>
                    <CustomButton
                        title={"Přihlásit se"}
                        onPress={() => signInAsync()}>
                    </CustomButton>
                </View>
            </View>
        </View>
    );
}

export const {width, height} = Dimensions.get('window');

const styles = StyleSheet.create({
    container: {
        flexDirection: 'column',
        flex: 1,
        alignItems: 'center',
        backgroundColor: '#225ED9'
    },
    logo: {
        width: 110,
        height: 110,
        justifyContent: 'center',
        marginBottom: 20,
    },
    header: {
        backgroundColor: "#40465e",
        padding: 20
    },
    headerContent: {
        padding: 30,
        alignItems: 'center',
    },
    image: {
        width: 60,
        height: 60,
    },
    name: {
        fontSize: 22,
        color: appColor.white,
        fontWeight: '600',
    },

    child: {
        height: 200,
        width,
        alignItems: 'center',
    },
    text: {
        marginTop: 20,
        color: appColor.white,
        opacity: 0.8,
        fontSize: width * 0.05,
        textAlign: 'center'
    },
    inputContainer: {
        borderBottomColor: '#4e5255',
        backgroundColor: '#454545',
        opacity: 1,
        borderRadius: 1.5,
        borderBottomWidth: 1,
        width: 250,
        height: 45,
        marginBottom: 20,
        flexDirection: 'row',
        alignItems: 'center'
    },
    inputs: {
        height: 45,
        marginLeft: 16,
        color: appColor.white,
        borderBottomColor: appColor.white,
        flex: 1
    },
    customInputContainer: {
        flexDirection: 'column',
        marginBottom: 30,
        width: '85%',
    },
    customInputLabel: {
        marginBottom: 5,
    },
    customInput: {
        height: 50,
        width: '100%',
        backgroundColor: appColor.white,
        borderRadius: 5,
        borderWidth: 1,
        borderColor: 'rgba(228, 228, 228, 0.6)',
        paddingLeft: 20,
        color: appColor.black,
    },
    buttonContainer: {
        height: 45,
        flexDirection: 'row',
        justifyContent: 'center',
        alignItems: 'center',
        marginTop: 20,
        marginBottom: 20,
        width: 250,
        borderRadius: 30,
    },
    loginButton: {
        backgroundColor: '#225ed9',
    },
    buttonText: {
        fontSize: 18,
        opacity: 0.5,
        color: appColor.white,
        marginBottom: 30
    }
});
