/*
/!**
 * @flow
 *!/


const {width: WINDOW_WIDTH} = Dimensions.get('window');

export default class NavigationScreen extends Component {

    state = {
        mapRegion: null,
        hasLocationPermissions: false,
        locationResult: null
    };

    constructor(props) {
        super(props);

        this.state = {
            isLoading: true,
            markers: [{}


            ],
        };
    }


    componentDidMount() {
        this._getLocationAsync();
    }

    _handleMapRegionChange = mapRegion => {
        console.log(mapRegion);
        this.setState({ mapRegion });
    };

    _getLocationAsync = async () => {
        let { status } = await Permissions.askAsync(Permissions.LOCATION);
        if (status !== 'granted') {
            this.setState({
                locationResult: 'Permission to access location was denied',
            });
        } else {
            this.setState({ hasLocationPermissions: true });
        }

        let location = await Location.getCurrentPositionAsync({});
        this.setState({ locationResult: JSON.stringify(location) });

        // Center the map on the location we just fetched.
        this.setState({mapRegion: { latitude: location.coords.latitude, longitude: location.coords.longitude, latitudeDelta: 0.0922, longitudeDelta: 0.0421 }});
    };

    render() {
        return (
            <View style={styles.container}>
                {
                    this.state.locationResult === null ?
                        <Text>Finding your current location...</Text> :
                        this.state.hasLocationPermissions === false ?
                            <Text>Location permissions are not granted.</Text> :
                            this.state.mapRegion === null ?
                                <Text>Map region doesn't exist.</Text> :

                                <View>
                                    <MapView
                                        provider='google'
                                        style={{ alignSelf: 'stretch', height: 350 }}
                                        region={this.state.mapRegion}
                                        onRegionChange={this._handleMapRegionChange}
                                    />



                                    <MapView
                                        region={this.state.region}
                                        onRegionChange={this.onRegionChange}
                                    >
                                    </MapView>
                                    <View style={styles.formContent}>
                                        <View style={styles.inputContainer}>
                                            <Image style={[styles.icon, styles.inputIcon]} source={{uri: 'https://png.icons8.com/search/androidL/100/000000'}}/>
                                            <TextInput style={styles.inputs}
                                                       ref={'txtPassword'}
                                                       placeholder="Search"
                                                       underlineColorAndroid='transparent'
                                                       />
                                        </View>
                                    </View>
                                </View>
                }
            </View>

        );
    }
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        backgroundColor: '#ecf0f1',
    },
    formContent:{
        flexDirection: 'row',
        marginTop:30,
    },
    inputContainer: {
        borderBottomColor: '#F5FCFF',
        backgroundColor: '#FFFFFF',
        borderRadius:10,
        borderBottomWidth: 1,
        height:45,
        flexDirection: 'row',
        alignItems:'center',
        flex:1,
        margin:10,
    },
    icon:{
        width:30,
        height:30,
    },
    iconBtnSearch:{
        alignSelf:'center'
    },
    inputs:{
        height:45,
        marginLeft:16,
        borderBottomColor: '#FFFFFF',
        flex:1,
    },
    paragraph: {
        margin: 24,
        fontSize: 18,
        fontWeight: 'bold',
        textAlign: 'center',
        color: '#34495e',
    },

});
*/

import React, {Component} from 'react';
import {WebView} from 'react-native-webview';

export default class NavigationScreen extends Component {
    render() {
        return (
            <WebView
                source={{uri: 'https://www.google.com/maps/d/u/0/viewer?mid=15_KMNdUtjTn3dJXPwnaeI7XA8332t1pM&ll=50.13013065730599%2C14.374481822004782&z=16'}}
                startInLoadingState={true}
            />
        );
    }
}
