import * as React from "react";
import {StyleSheet, View, ImageBackground, StatusBar, TouchableOpacity, Linking} from "react-native";
import {LinearGradient} from 'expo-linear-gradient';
import {RobotoText} from "components/utils/texts/StyledText";
import {RobotoBoldText} from "components/utils/texts/StyledText";
import {useTheme} from "react-native-paper";

import {appColor} from "constants/Colors";
import ArrowLightLeftIcon from 'assets/svg/arrowLightLeftIcon.svg';
import TimeIcon from "assets/svg/timeIcon.svg";
import {WebView} from "react-native-webview";

interface Props {
    title: string,
    content: string,
    imagePath: string;
    date: string,
    categoryTitle: string,
    categoryColor: any,
    contentUrl: string,
}

export const NewsFeedScreenItem: React.FC = (props: any) => {
    const theme = useTheme();
    const params:Props = props.route.params;
    const navigation = props.navigation;

    /* JS edit web page - delete everything except content and restyle by theme */
    const jsCode = 'function hideElements() {for (var i = 0; i < document.body.children.length; i++) {if (!document.body.children[i].querySelectorAll(\'[role=\"article\"]\')[0]) {document.body.children[i].style.display = "none";}else{document.body.children[i].getElementsByTagName(\"footer\")[0].style.display = "none";document.body.style.backgroundColor = \"' + theme.colors.surface +'\";document.body.children[i].style.color = \"' + theme.colors.text +'\";document.body.children[i].style.paddingTop=\"40px\";document.getElementsByClassName(\"widget-scroll-to-top\")[0].remove();}}} hideElements();';

    const shouldStartLoadWithRequest = (req) => {
        if(req.url != params.contentUrl) {
            Linking.openURL(req.url).then(null);
            return false;
        }
        return true;
    };

    return (
        <View style={[styles.container, {backgroundColor: theme.colors.surface}]}>
            <StatusBar barStyle="light-content"/>
            <View style={{backgroundColor: theme.colors.placeholder}}>
                <ImageBackground source={{uri: params.imagePath}} style={{height: 230, backgroundColor: appColor.gray}} imageStyle={{resizeMode: 'cover'}} />
                <LinearGradient
                    colors={[appColor.black, 'transparent']}
                    style={{width: '100%', height: 230, position: 'absolute', left: 0, right: 0, top: 0,}}
                />
                <TouchableOpacity style={[styles.header, {top: 50, height: 40, width: 20}]} onPress={() => navigation.goBack()}>
                    <ArrowLightLeftIcon height={15} width={15} stroke={appColor.white}/>
                </TouchableOpacity>
                <RobotoBoldText style={[styles.header, {top: 100}]}>{params.title}</RobotoBoldText>
                <View style={[styles.detail, {flexDirection: "row", alignItems: 'center', backgroundColor: theme.colors.surface}]}>
                    <RobotoBoldText style={{color: params.categoryColor, fontSize: 11, paddingLeft: 13, paddingRight: 13}}>{params.categoryTitle}</RobotoBoldText>
                    <View style={{flexDirection: "row", alignItems: 'center', paddingLeft: 13, paddingRight: 13}}>
                        <TimeIcon height={20} stroke={appColor.gray}/>
                        <RobotoText style={{color: appColor.gray, fontSize: 11, paddingLeft: 5}}>{params.date}</RobotoText>
                    </View>
                </View>
            </View>
            <WebView source={{uri: params.contentUrl}}
                     injectedJavaScript={jsCode}
                     onMessage={() => {}}
                        //TODO: Still loading animation after redirect on load
                     startInLoadingState={true}
                     javascriptenabled={true}
                     onShouldStartLoadWithRequest={shouldStartLoadWithRequest}
                        //TODO: WebView transparent backgroundColor doesn't work for iOS
                     style={{backgroundColor: 'transparent'}}
            />
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        height: '100%',
        width: '100%',
    },
    header:{
        position: "absolute",
        paddingLeft: 27,
        paddingRight: 27,
        fontSize: 18,
        color: appColor.white,
    },
    detail:{
        position: "absolute",
        bottom: 20,
        height: 34,
        marginLeft: 27,
        borderRadius: 5,
    },
});

export default NewsFeedScreenItem;