import * as React from "react";
import {ScrollView, StyleSheet, View, ActivityIndicator, RefreshControl} from "react-native";
import {NewsFeedItem} from "components/library/NewsFeedItem";
import {TabFilter} from "components/library/TabFilter";
import {useTheme} from "react-native-paper";
import {NewsListScreens} from "navigation/Screens";
import {getText} from "locales/Locales";

import {useFetchNewsFeed} from "services/NewsFeedService";
import {appColor} from "constants/Colors";
import {useNavigation} from "@react-navigation/native";
import {StackNavigationProp} from "@react-navigation/stack";
import {useState} from "react";

export interface websiteSource {
    key: string;
    title: string;
    value: string;
    color: any;
}

export interface NewsFeedData {
    id: number;
    title: string;
    text: string;
    url: string;
    imgSrc: string,
    websiteSource: string
    date: string,
}

export const NewsFeedScreen: React.FC = () => {
    const theme = useTheme();
    const navigation = useNavigation<StackNavigationProp<any>>();
    const [filterCategory, setFilterCategory] = useState<string>("");

    let websiteSources: websiteSource[] = [
        { key: "ALL", title: getText('newsListScreen.filter.all'), value: "" , color: appColor.black},
        { key: "PEF", title: getText('newsListScreen.filter.news'), value: "PEF", color: appColor.red},
        { key: "KNIHOVNA", title: getText('newsListScreen.filter.library'), value: "KNIHOVNA", color: appColor.blue},
        { key: "IZUN", title: getText('newsListScreen.filter.izun'), value: "IZUN", color: '#219653'},
        { key: "CZUWP", title: getText('newsListScreen.filter.czu'), value: "CZUWP", color: '#219653' },
    ];

    const loadData = (websiteSource): NewsFeedData =>  {
        return useFetchNewsFeed('https://appbackend.pef.czu.cz/news/feed?websiteSource=' + websiteSource);
    }

    const {loading, newsFeed}: any = loadData(filterCategory);

    const getDataByCategory = (value) => {
        setFilterCategory(value)
    }

    const onRefresh = () => {
        console.log("refresh");
        //TODO: Finish refreshing
    }

    return (
        <View style={styles.container}>
            <TabFilter
                filterItems={websiteSources}
                callback={getDataByCategory.bind(this)}
            />
            <View style={[styles.container, loading && {justifyContent: 'center'}, {backgroundColor: theme.colors.surface}]}>
                {loading && <ActivityIndicator size="large" color={theme.colors.text}/>}
                {!loading && <ScrollView contentContainerStyle={null}
                    refreshControl={
                        <RefreshControl
                            refreshing={loading}
                            onRefresh={onRefresh}
                        />}>
                    {loading ? <ActivityIndicator/> : newsFeed.map(newsFeedItem =>{

                        return(
                                <NewsFeedItem
                                        key={newsFeedItem.id}
                                        title={newsFeedItem.title}
                                        description={newsFeedItem.text}
                                        imagePath={newsFeedItem.imgSrc}
                                        category={newsFeedItem.websiteSource}
                                        date={newsFeedItem.date}
                                        contentUrl={newsFeedItem.url}
                                        categories={websiteSources}
                                        navigation={navigation}
                                        target={NewsListScreens.DETAIL}
                                    />
                                );
                          })
                    }
                </ScrollView>}
            </View>
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        height: '97%',
        width: '100%',
    },
});

export default NewsFeedScreen;