import React from "react";
import {Dimensions, Image, ImageBackground, StyleSheet, View} from "react-native";
import {Button} from "react-native-elements";
import {RobotoBoldText, RobotoText} from "components/utils/texts/StyledText";
import appText from "constants/Colors";
import {getText} from "locales/Locales";
import {AppModules} from "navigation/Screens";
import CredentialsService from "services/InternalStoreService";
import {useNavigation} from "@react-navigation/native";
import {StackNavigationProp} from "@react-navigation/stack";

const {width: WINDOW_WIDTH} = Dimensions.get('window');


export const AlephCard: React.FC<{ }> = () => {

    const navigation = useNavigation<StackNavigationProp<any>>();


    const login = async () => {
        const user = await CredentialsService.getLibraryUser();
        //todo provolat api jestli si nezmenil napriklad heslo
        if (user) {
            navigation.navigate(AppModules.LIBRARY);
        } else {
            navigation.navigate(AppModules.LIBRARY_LOGIN)
        }
    }

    return (
        <ImageBackground style={styles.container} source={require('assets/Aleph.png')}>
            <RobotoBoldText style={[{
                fontSize: 20,
                color: appText.appText,
                padding: 5
            }]}>{getText("homeScreen.alephCard.header")}</RobotoBoldText>
            <View style={{flexDirection: "row", alignItems: 'center', height: 30}}>
                <Image source={require('assets/clock-circular-outline.png')} style={{height: 15}}
                       resizeMode='contain'/>
                <RobotoText style={[{color: '#e24040'}]}>{getText("homeScreen.alephCard.notification")}</RobotoText>
            </View>

            <Button
                title={getText("homeScreen.alephCard.runGuide")}
                titleStyle={{fontSize: 13, color: '#3672EC'}}
                buttonStyle={styles.buttonStyle}
                containerStyle={{marginLeft: 5, marginRight: 0}}
                onPress={login}/>
            <View style={styles.borrowContainer}>
                <View style={{height: '100%', justifyContent: 'center'}}>
                    <Image source={require('assets/exclamation-mark.png')} style={{height: 15}}
                           resizeMode='contain'/>
                </View>
                <RobotoText style={[{
                    color: '#fec606',
                    padding: 5
                }]}>{getText("homeScreen.alephCard.afterDeadline")}</RobotoText>
            </View>
        </ImageBackground>
    );

}

const styles = StyleSheet.create({
    container: {
        margin: 10,
        width: WINDOW_WIDTH,
        height: 200,
        padding: 20,
        flex: 1,
        marginLeft: 10,
        marginRight: 10
    },

    buttonStyle: {
        padding: 5,
        height: 35,
        width: 150,
        alignSelf: 'flex-start',
        backgroundColor: "#FFFFFF",
        borderRadius: 20,
        marginTop: 10,
        marginBottom: 10
    },

    borrowContainer: {
        flexDirection: "row",
        height: 30,
        padding: 1,
        alignSelf: 'flex-start',
        backgroundColor: '#000000',
        borderRadius: 5,
        opacity: 0.55,
        marginTop: 15
    }
});
