import React, {Component} from "react";
import {Dimensions, ImageBackground, StyleSheet, View} from "react-native";
import {Button, Icon} from "react-native-elements";
import {RobotoBoldText, RobotoText} from "components/utils/texts/StyledText";
import appText from "constants/Colors";
import {getText} from "locales/Locales";
import {AppModules} from "navigation/Screens";

interface Props {
    navigation: any
}

const {width: WINDOW_WIDTH} = Dimensions.get('window');

export default class NavigationCard extends Component<Props> {
    constructor(props) {
        super(props);
    }

    render() {

        const { navigation } = this.props;

        return (
            <ImageBackground style={styles.container} resizeMode="cover" source={require('assets/navigace.png')}>

                <RobotoBoldText style={[{fontSize: 20, color: appText.appText, padding: 5, marginLeft: 25}]}>{getText("homeScreen.navigationCard.header")}</RobotoBoldText>
                <Button
                    title={getText("homeScreen.navigationCard.runGuide")}
                    titleStyle={{fontSize: 13, color: '#3672EC'}}
                    buttonStyle={styles.buttonStyle}
                    containerStyle={{marginLeft: 25, marginRight: 0, marginTop: 25}}
                    onPress={() => navigation.navigate(AppModules.NAVIGATION, { accessToken: 'Authenticated' })}
                />
                <View style={{flexDirection: "row", alignItems: 'center', height: 20, marginLeft: 25, marginTop: 15}}>
                    <Icon
                        name='navigation'
                        type='feather'
                        color='#3672EC'
                    />
                    <RobotoText style={[{fontSize: 12, color: '#3672EC', marginLeft: 5, padding: 5}]}>{getText("homeScreen.navigationCard.currentLocation")}</RobotoText>
                </View>
            </ImageBackground>
        );
    }
}

const styles = StyleSheet.create({
    container: {
        color: "#40465e",
        margin: 10,
        width: WINDOW_WIDTH + 26,
        height: 200,
        padding: 20,
        flex: 1,
        marginLeft: 5,
        marginRight: 5,
        borderRadius: 10,
        backgroundColor: '#000000'
    },

    buttonStyle: {
        padding: 10,
        height: 35,
        width: 150,
        alignSelf: 'flex-start',
        backgroundColor: "#FFFFFF",
        borderRadius: 20,
        marginTop: 10,
        marginBottom: 10
    },

    borrowContainer: {
        flexDirection: "row",
        height: 30,
        padding: 1,
        alignSelf: 'flex-start',
        backgroundColor: '#000000',
        borderRadius: 5,
        opacity: 0.55,
        marginTop: 15
    }
});
