import React from 'react';
import {createBottomTabNavigator} from '@react-navigation/bottom-tabs';
import {Ionicons} from '@expo/vector-icons';
import {InitialProps} from "expo/build/launch/withExpoRoot.types";
import {StyleConstants} from "style/StyleConstants";
import {FeedScreen} from "screens/library/FeedScreen";
import {InfoScreen} from "screens/library/InfoScreen";
import {LibraryCatalogScreens, LibraryDashboardScreens} from "navigation/Screens";
import AlephCatalogScreen from "screens/library/AlephCatalogScreen";
import {BookDetailScreen} from "screens/library/BookDetailScreen";
import {BookItemScreen} from "screens/library/BookItemsScreen";
import {createStackNavigator} from "@react-navigation/stack";
import {DashBoardScreen} from "screens/library/DashBoardScreen";
import {ReservationsScreen} from "screens/library/ReservationsScreen";
import {LoansScreen} from "screens/library/LoansScreen";
import {HistoryScreen} from "screens/library/HistoryScreen";


const Stack = createStackNavigator();

export const LibraryDashboardStack = () => {
    return (
        <Stack.Navigator screenOptions={{headerShown: false}}>
            <Stack.Screen name={LibraryDashboardScreens.DASHBOARD} component={DashBoardScreen}/>
            <Stack.Screen name={LibraryDashboardScreens.RESERVATIONS} component={ReservationsScreen}
                          options={{
                              headerShown: true,
                              title: 'Rezervace',
                              headerTintColor: StyleConstants.PRIMARY_BLUE_COLOR,
                              headerTitleStyle: {
                                  fontWeight: 'bold',
                              },
                          }}
            />
            <Stack.Screen name={LibraryDashboardScreens.LOANS} component={LoansScreen}
                          options={{
                              headerShown: true,
                              title: 'Výpůjčky',
                              headerTintColor: StyleConstants.PRIMARY_BLUE_COLOR,
                              headerTitleStyle: {
                                  fontWeight: 'bold',
                              },
                          }}
            />
            <Stack.Screen name={LibraryDashboardScreens.HISTORY} component={HistoryScreen}
                          options={{
                              headerShown: true,
                              title: 'Historie výpůjček',
                              headerTintColor: StyleConstants.PRIMARY_BLUE_COLOR,
                              headerTitleStyle: {
                                  fontWeight: 'bold',
                              },
                          }}
            />
            <Stack.Screen name={LibraryDashboardScreens.BOOK_DETAIL} component={BookDetailScreen}
                          options={{
                              headerShown: true,
                              title: 'Detail knihy',
                              headerTintColor: StyleConstants.PRIMARY_BLUE_COLOR,
                              headerTitleStyle: {
                                  fontWeight: 'bold',
                              },
                          }}
            />
        </Stack.Navigator>
    );
};

export const LibraryCatalogStack = () => {
    return (
        <Stack.Navigator screenOptions={{headerShown: false}}>
            <Stack.Screen name={LibraryCatalogScreens.CATALOG} component={AlephCatalogScreen}/>
            <Stack.Screen name={LibraryCatalogScreens.DETAIL} component={BookDetailScreen}
                          options={{
                              headerShown: true,
                              title: 'Detail Knihy',
                              headerTintColor: StyleConstants.PRIMARY_BLUE_COLOR,
                              headerTitleStyle: {
                                  fontWeight: 'bold',
                              },
                          }}
            />
            <Stack.Screen name={LibraryCatalogScreens.BOOK_ITEMS} component={BookItemScreen}
                          options={{
                              headerShown: true,
                              title: 'Exempláře',
                              headerTintColor: StyleConstants.PRIMARY_BLUE_COLOR,
                              headerTitleStyle: {
                                  fontWeight: 'bold',
                              },
                          }}
            />
        </Stack.Navigator>
    );
};

export const LibraryTabStack: React.FC<InitialProps> = (initialProps: InitialProps) => {

    const Tab = createBottomTabNavigator();

    return (
        <Tab.Navigator screenOptions={({route}) => ({
            tabBarIcon: ({focused, color, size}) => {
                let iconName;
                switch (route.name) {
                    case 'Info' :
                        iconName = 'ios-information-circle';
                        break;
                    case 'Katalog' :
                        iconName = 'ios-search';
                        break;
                    case 'Home' :
                        iconName = 'ios-home';
                        break;
                    case 'Aktuality' :
                        iconName = 'logo-rss';
                        break;
                }

                // You can return any component that you like here!
                return <Ionicons name={iconName} size={size} color={color}/>;
            },
        })}
        >
            <Tab.Screen name="Home" component={LibraryDashboardStack}/>
            <Tab.Screen name="Katalog" component={LibraryCatalogStack}/>
            <Tab.Screen name="Aktuality" component={FeedScreen}/>
            <Tab.Screen name="Info" component={InfoScreen}/>
        </Tab.Navigator>
    );
};



