import React from 'react';
import {ActivityIndicator, FlatList, View} from "react-native";
import CredentialsService from "services/InternalStoreService";
import LibraryUser from "model/library/LibraryUser";
import AlephService from "services/AlephService";
import {BookListItem} from "components/library/BookListItem";
import {Button} from "react-native-elements";
import Constants from "expo-constants";
import LoanBook from "model/library/LoanBook";

interface Props {
    route: any;
}

interface State {
    loans: LoanBook[],
    loading: boolean
}

export const LoansScreen: React.FC<Props> = (props: Props) => {

    let userId: string;

    const [state, setState] = React.useState<State>({loading: false, loans: props.route.params.loans});

    const loadLoans = async () => {
        setState({...state, loading: true});
        let user: LibraryUser = await CredentialsService.getLibraryUser();
        user = await AlephService.getUserInfo(user.username, user.password);
        userId = user.id;
        setState({loading: false, loans: user.loans});
    };

    const renderItem = ({ item }: { item: LoanBook }) => (
       <BookListItem title={item.title} author={item.author} year={item.year} isbn={item.isbn}
                      // onPress={() => RootNavigation.navigate('Details', {book: item})}
        >
            <Button title={'Prodloužit výpůjčku'} onPress={
                async () => {
                    await AlephService.renewLoan(item.barCode, userId);
                    loadLoans();
                }
            }/>
        </BookListItem>
    );

    return (
      <View style={ {paddingTop: Constants.statusBarHeight}}>
          {state.loading && <ActivityIndicator/>}
          {!state.loading && <FlatList<LoanBook> data={state.loans} renderItem={renderItem}/>}
      </View>
    );


};
