import React from 'react';
import {ActivityIndicator, Alert, FlatList} from "react-native";
import CredentialsService from "services/InternalStoreService";
import LibraryUser from "model/library/LibraryUser";
import AlephService from "services/AlephService";
import ReservationBook from "model/library/ReservationBook";
import {BookListItem} from "components/library/BookListItem";
import {Button} from "react-native-elements";
import {useNavigation} from "@react-navigation/native";
import {StackNavigationProp} from "@react-navigation/stack";
import {GLOBAL_STYLES} from "style/GlobalStyles";
import {MainView} from "components/utils/view/MainView";
import {LibraryDashboardScreens} from "navigation/Screens";

interface Props {
    route: any;
}

interface State {
    reservations: ReservationBook[],
    loading: boolean
}

export const ReservationsScreen: React.FC<Props> = (props: Props) => {

    const [state, setState] = React.useState<State>({loading: false, reservations: props.route.params.reservations});
    const navigation = useNavigation<StackNavigationProp<any>>();


    const loadReservations = async () => {
        setState({...state, loading: true});
        let user: LibraryUser = await CredentialsService.getLibraryUser();
        user = await AlephService.getUserInfo(user.username, user.password);
        setState({loading: false, reservations: user.reservations});
    };

    const renderItem = ({ item }: { item: ReservationBook }) => (
       <BookListItem title={item.title} author={item.author} year={item.year} isbn={item.isbn}
                      onPress={() => navigation.navigate(LibraryDashboardScreens.BOOK_DETAIL, {book: item})}
        >
           <Button title={'Zrušit rezervaci'} onPress={
                async () => {
                    try {
                        setState({...state, loading: true});
                        const response = await AlephService.cancelHoldRequest(item.docNumber, item.itemSequence, item.sequence);
                        setState({...state, loading: false});
                        console.log(response.status);
                        if(response.status === 404 || !response.ok) {
                            Alert.alert("Zrušení rezervace", "Došlo k chybě při rušení rezervace položky");
                        } else {
                            Alert.alert("Zrušení rezervace", "Zrušení rezervace bylo úspěšné");
                            const removedReservationState = state.reservations.filter(
                                value => value!== item
                               );
                            await loadReservations();
                            setState({...state, reservations: removedReservationState});
                        }
                    } catch (e) {
                            console.log(e);
                            setState({...state, loading: false});
                            Alert.alert("Zrušení rezervace", "Došlo k chybě při rušení rezervace položky");
                    }
            }

            }/>
       </BookListItem>
    );

    return (
      <MainView>
          {state.loading && <ActivityIndicator style={GLOBAL_STYLES.fullScreenIndicator}/>}
          <FlatList<ReservationBook> data={state.reservations} renderItem={renderItem} keyExtractor={item => item.sequence}/>
      </MainView>
    );


};
